@@ -31,14 +31,12 @@ from nova.api.metadata import password
 from nova.api.metadata import vendordata
 from nova.api.metadata import vendordata_dynamic
 from nova.api.metadata import vendordata_json
-from nova import availability_zones as az
 from nova import block_device
 from nova.cells import opts as cells_opts
 from nova.cells import rpcapi as cells_rpcapi
 import nova.conf
 from nova import context
 from nova import exception
-from nova.i18n import _LI, _LW
 from nova import network
 from nova.network.security_group import openstack_driver
 from nova import objects
@@ -126,13 +124,22 @@ class InstanceMetadata(object):
 
         ctxt = context.get_admin_context()
 
+        # NOTE(danms): Sanitize the instance to limit the amount of stuff
+        # inside that may not pickle well (i.e. context). We also touch
+        # some of the things we'll lazy load later to make sure we keep their
+        # values in what we cache.
+        instance.ec2_ids
+        instance.keypairs
+        instance.device_metadata
+        instance = objects.Instance.obj_from_primitive(
+            instance.obj_to_primitive())
+
         # The default value of mimeType is set to MIME_TYPE_TEXT_PLAIN
         self.set_mimetype(MIME_TYPE_TEXT_PLAIN)
         self.instance = instance
         self.extra_md = extra_md
 
-        self.availability_zone = az.get_instance_availability_zone(ctxt,
-                                                                   instance)
+        self.availability_zone = instance.get('availability_zone')
 
         secgroup_api = openstack_driver.get_openstack_security_group_driver()
         self.security_groups = secgroup_api.get_instance_security_groups(
@@ -411,6 +418,8 @@ class InstanceMetadata(object):
                         bus = 'scsi'
                     elif isinstance(device.bus, metadata_obj.IDEDeviceBus):
                         bus = 'ide'
+                    elif isinstance(device.bus, metadata_obj.XenDeviceBus):
+                        bus = 'xen'
                     else:
                         LOG.debug('Metadata for device with unknown bus %s '
                                   'has not been included in the '
@@ -525,8 +534,8 @@ class InstanceMetadata(object):
                     values = self.vendordata_providers[provider].get()
                     for key in list(values):
                         if key in j:
-                            LOG.warning(_LW('Removing duplicate metadata key: '
-                                            '%s'), key, instance=self.instance)
+                            LOG.warning('Removing duplicate metadata key: %s',
+                                        key, instance=self.instance)
                             del values[key]
                     j.update(values)
 
@@ -671,7 +680,7 @@ class RouteConfiguration(object):
 def get_metadata_by_address(address):
     ctxt = context.get_admin_context()
     fixed_ip = network.API().get_fixed_ip_by_address(ctxt, address)
-    LOG.info(_LI('Fixed IP %(ip)s translates to instance UUID %(uuid)s'),
+    LOG.info('Fixed IP %(ip)s translates to instance UUID %(uuid)s',
              {'ip': address, 'uuid': fixed_ip['instance_uuid']})
 
     return get_metadata_by_instance_id(fixed_ip['instance_uuid'],
@@ -688,14 +697,14 @@ def get_metadata_by_instance_id(instance_id, address, ctxt=None):
     try:
         im = objects.InstanceMapping.get_by_instance_uuid(ctxt, instance_id)
     except exception.InstanceMappingNotFound:
-        LOG.warning(_LW('Instance mapping for %(uuid)s not found; '
-                        'cell setup is incomplete'), {'uuid': instance_id})
+        LOG.warning('Instance mapping for %(uuid)s not found; '
+                    'cell setup is incomplete', {'uuid': instance_id})
         instance = objects.Instance.get_by_uuid(ctxt, instance_id,
                                                 expected_attrs=attrs)
         return InstanceMetadata(instance, address)
 
-    with context.target_cell(ctxt, im.cell_mapping):
-        instance = objects.Instance.get_by_uuid(ctxt, instance_id,
+    with context.target_cell(ctxt, im.cell_mapping) as cctxt:
+        instance = objects.Instance.get_by_uuid(cctxt, instance_id,
                                                 expected_attrs=attrs)
         return InstanceMetadata(instance, address)
 
