@@ -19,18 +19,18 @@
 from oslo_utils import importutils
 import webob
 
+from nova.api.openstack.api_version_request \
+    import MAX_PROXY_API_SUPPORT_VERSION
 from nova.api.openstack import common
 from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 import nova.conf
 from nova.i18n import _
+from nova.policies import baremetal_nodes as bn_policies
 
 ironic_client = importutils.try_import('ironicclient.client')
 ironic_exc = importutils.try_import('ironicclient.exc')
 
-ALIAS = "os-baremetal-nodes"
-authorize = extensions.os_compute_authorizer(ALIAS)
-
 node_fields = ['id', 'cpus', 'local_gb', 'memory_mb', 'pm_address',
                'pm_user', 'service_host', 'terminal_port', 'instance_uuid']
 
@@ -39,21 +39,6 @@ node_ext_fields = ['uuid', 'task_state', 'updated_at', 'pxe_config_path']
 interface_fields = ['id', 'address', 'datapath_id', 'port_no']
 
 CONF = nova.conf.CONF
-CONF.import_opt('api_version',
-                'nova.virt.ironic.driver',
-                group='ironic')
-CONF.import_opt('api_endpoint',
-                'nova.virt.ironic.driver',
-                group='ironic')
-CONF.import_opt('admin_username',
-                'nova.virt.ironic.driver',
-                group='ironic')
-CONF.import_opt('admin_password',
-                'nova.virt.ironic.driver',
-                group='ironic')
-CONF.import_opt('admin_tenant_name',
-                'nova.virt.ironic.driver',
-                group='ironic')
 
 
 def _check_ironic_client_enabled():
@@ -73,7 +58,11 @@ def _get_ironic_client():
               'os_endpoint_type': 'public',
               'insecure': 'true',
               'ironic_url': CONF.ironic.api_endpoint}
-    icli = ironic_client.get_client(CONF.ironic.api_version, **kwargs)
+    # NOTE(mriedem): The 1 api_version arg here is the only valid value for
+    # the client, but it's not even used so it doesn't really matter. The
+    # ironic client wrapper in the virt driver actually uses a hard-coded
+    # microversion via the os_ironic_api_version kwarg.
+    icli = ironic_client.get_client(1, **kwargs)
     return icli
 
 
@@ -95,10 +84,11 @@ class BareMetalNodeController(wsgi.Controller):
             d[f] = node_ref.get(f)
         return d
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @extensions.expected_errors((404, 501))
     def index(self, req):
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(bn_policies.BASE_POLICY_NAME)
         nodes = []
         # proxy command to Ironic
         _check_ironic_client_enabled()
@@ -115,10 +105,11 @@ class BareMetalNodeController(wsgi.Controller):
             nodes.append(node)
         return {'nodes': nodes}
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @extensions.expected_errors((404, 501))
     def show(self, req, id):
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(bn_policies.BASE_POLICY_NAME)
         # proxy command to Ironic
         _check_ironic_client_enabled()
         icli = _get_ironic_client()
@@ -140,40 +131,24 @@ class BareMetalNodeController(wsgi.Controller):
             node['interfaces'].append({'address': port.address})
         return {'node': node}
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @extensions.expected_errors(400)
     def create(self, req, body):
-        _no_ironic_proxy("port-create")
+        _no_ironic_proxy("node-create")
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @extensions.expected_errors(400)
     def delete(self, req, id):
-        _no_ironic_proxy("port-create")
+        _no_ironic_proxy("node-delete")
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @wsgi.action('add_interface')
     @extensions.expected_errors(400)
     def _add_interface(self, req, id, body):
         _no_ironic_proxy("port-create")
 
+    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
     @wsgi.action('remove_interface')
     @extensions.expected_errors(400)
     def _remove_interface(self, req, id, body):
         _no_ironic_proxy("port-delete")
-
-
-class BareMetalNodes(extensions.V21APIExtensionBase):
-    """Admin-only bare-metal node administration."""
-
-    name = "BareMetalNodes"
-    alias = ALIAS
-    version = 1
-
-    def get_resources(self):
-        resource = [extensions.ResourceExtension(ALIAS,
-                BareMetalNodeController(),
-                member_actions={"action": "POST"})]
-        return resource
-
-    def get_controller_extensions(self):
-        """It's an abstract function V21APIExtensionBase and the extension
-        will not be loaded without it.
-        """
-        return []
