@@ -25,13 +25,12 @@ from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import compute
+from nova import context as nova_context
 from nova import exception
-from nova.i18n import _LI
 from nova import objects
+from nova.policies import hosts as hosts_policies
 
 LOG = logging.getLogger(__name__)
-ALIAS = 'os-hosts'
-authorize = extensions.os_compute_authorizer(ALIAS)
 
 
 class HostController(wsgi.Controller):
@@ -40,6 +39,7 @@ class HostController(wsgi.Controller):
         self.api = compute.HostAPI()
         super(HostController, self).__init__()
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors(())
     def index(self, req):
         """Returns a dict in the format
@@ -59,7 +59,7 @@ class HostController(wsgi.Controller):
         |    {'host_name': 'network1.host.com',
         |     'service': 'network',
         |     'zone': 'internal'},
-        |    {'host_name': 'netwwork2.host.com',
+        |    {'host_name': 'network2.host.com',
         |     'service': 'network',
         |     'zone': 'internal'},
         |    {'host_name': 'compute1.host.com',
@@ -80,13 +80,13 @@ class HostController(wsgi.Controller):
 
         """
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(hosts_policies.BASE_POLICY_NAME)
         filters = {'disabled': False}
         zone = req.GET.get('zone', None)
         if zone:
             filters['availability_zone'] = zone
         services = self.api.service_get_all(context, filters=filters,
-                                            set_zones=True)
+                                            set_zones=True, all_cells=True)
         hosts = []
         api_services = ('nova-osapi_compute', 'nova-ec2', 'nova-metadata')
         for service in services:
@@ -96,6 +96,7 @@ class HostController(wsgi.Controller):
                               'zone': service['availability_zone']})
         return {'hosts': hosts}
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors((400, 404, 501))
     @validation.schema(hosts.update)
     def update(self, req, id, body):
@@ -116,7 +117,7 @@ class HostController(wsgi.Controller):
             return val == "enable"
 
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(hosts_policies.BASE_POLICY_NAME)
         # See what the user wants to 'update'
         status = body.get('status')
         maint_mode = body.get('maintenance_mode')
@@ -138,14 +139,13 @@ class HostController(wsgi.Controller):
         """Start/Stop host maintenance window. On start, it triggers
         guest VMs evacuation.
         """
-        LOG.info(_LI("Putting host %(host_name)s in maintenance mode "
-                    "%(mode)s."),
-                  {'host_name': host_name, 'mode': mode})
+        LOG.info("Putting host %(host_name)s in maintenance mode %(mode)s.",
+                 {'host_name': host_name, 'mode': mode})
         try:
             result = self.api.set_host_maintenance(context, host_name, mode)
         except NotImplementedError:
             common.raise_feature_not_supported()
-        except exception.HostNotFound as e:
+        except (exception.HostNotFound, exception.HostMappingNotFound) as e:
             raise webob.exc.HTTPNotFound(explanation=e.format_message())
         except exception.ComputeServiceUnavailable as e:
             raise webob.exc.HTTPBadRequest(explanation=e.format_message())
@@ -159,15 +159,14 @@ class HostController(wsgi.Controller):
                         on the host.
         """
         if enabled:
-            LOG.info(_LI("Enabling host %s."), host_name)
+            LOG.info("Enabling host %s.", host_name)
         else:
-            LOG.info(_LI("Disabling host %s."), host_name)
+            LOG.info("Disabling host %s.", host_name)
         try:
-            result = self.api.set_host_enabled(context, host_name=host_name,
-                                               enabled=enabled)
+            result = self.api.set_host_enabled(context, host_name, enabled)
         except NotImplementedError:
             common.raise_feature_not_supported()
-        except exception.HostNotFound as e:
+        except (exception.HostNotFound, exception.HostMappingNotFound) as e:
             raise webob.exc.HTTPNotFound(explanation=e.format_message())
         except exception.ComputeServiceUnavailable as e:
             raise webob.exc.HTTPBadRequest(explanation=e.format_message())
@@ -178,26 +177,28 @@ class HostController(wsgi.Controller):
     def _host_power_action(self, req, host_name, action):
         """Reboots, shuts down or powers up the host."""
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(hosts_policies.BASE_POLICY_NAME)
         try:
-            result = self.api.host_power_action(context, host_name=host_name,
-                                                action=action)
+            result = self.api.host_power_action(context, host_name, action)
         except NotImplementedError:
             common.raise_feature_not_supported()
-        except exception.HostNotFound as e:
+        except (exception.HostNotFound, exception.HostMappingNotFound) as e:
             raise webob.exc.HTTPNotFound(explanation=e.format_message())
         except exception.ComputeServiceUnavailable as e:
             raise webob.exc.HTTPBadRequest(explanation=e.format_message())
         return {"host": host_name, "power_action": result}
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors((400, 404, 501))
     def startup(self, req, id):
         return self._host_power_action(req, host_name=id, action="startup")
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors((400, 404, 501))
     def shutdown(self, req, id):
         return self._host_power_action(req, host_name=id, action="shutdown")
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors((400, 404, 501))
     def reboot(self, req, id):
         return self._host_power_action(req, host_name=id, action="reboot")
@@ -206,17 +207,17 @@ class HostController(wsgi.Controller):
     def _get_total_resources(host_name, compute_node):
         return {'resource': {'host': host_name,
                              'project': '(total)',
-                             'cpu': compute_node['vcpus'],
-                             'memory_mb': compute_node['memory_mb'],
-                             'disk_gb': compute_node['local_gb']}}
+                             'cpu': compute_node.vcpus,
+                             'memory_mb': compute_node.memory_mb,
+                             'disk_gb': compute_node.local_gb}}
 
     @staticmethod
     def _get_used_now_resources(host_name, compute_node):
         return {'resource': {'host': host_name,
                              'project': '(used_now)',
-                             'cpu': compute_node['vcpus_used'],
-                             'memory_mb': compute_node['memory_mb_used'],
-                             'disk_gb': compute_node['local_gb_used']}}
+                             'cpu': compute_node.vcpus_used,
+                             'memory_mb': compute_node.memory_mb_used,
+                             'disk_gb': compute_node.local_gb_used}}
 
     @staticmethod
     def _get_resource_totals_from_instances(host_name, instances):
@@ -251,6 +252,7 @@ class HostController(wsgi.Controller):
                                     instance['ephemeral_gb'])
         return project_map
 
+    @wsgi.Controller.api_version("2.1", "2.42")
     @extensions.expected_errors(404)
     def show(self, req, id):
         """Shows the physical/usage resource given by hosts.
@@ -264,15 +266,18 @@ class HostController(wsgi.Controller):
                     'cpu': 1, 'memory_mb': 2048, 'disk_gb': 30}
         """
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(hosts_policies.BASE_POLICY_NAME)
         host_name = id
         try:
+            mapping = objects.HostMapping.get_by_host(context, host_name)
+            nova_context.set_target_cell(context, mapping.cell_mapping)
             compute_node = (
                 objects.ComputeNode.get_first_node_by_host_for_old_compat(
                     context, host_name))
-        except exception.ComputeHostNotFound as e:
+            instances = self.api.instance_get_all_by_host(context, host_name)
+        except (exception.ComputeHostNotFound,
+                exception.HostMappingNotFound) as e:
             raise webob.exc.HTTPNotFound(explanation=e.format_message())
-        instances = self.api.instance_get_all_by_host(context, host_name)
         resources = [self._get_total_resources(host_name, compute_node)]
         resources.append(self._get_used_now_resources(host_name,
                                                       compute_node))
@@ -283,21 +288,3 @@ class HostController(wsgi.Controller):
         for resource in six.itervalues(by_proj_resources):
             resources.append({'resource': resource})
         return {'host': resources}
-
-
-class Hosts(extensions.V21APIExtensionBase):
-    """Admin-only host administration."""
-
-    name = "Hosts"
-    alias = ALIAS
-    version = 1
-
-    def get_resources(self):
-        resources = [extensions.ResourceExtension(ALIAS,
-                HostController(),
-                member_actions={"startup": "GET", "shutdown": "GET",
-                        "reboot": "GET"})]
-        return resources
-
-    def get_controller_extensions(self):
-        return []
