@@ -32,9 +32,6 @@ from nova.objects import keypair as keypair_obj
 from nova.policies import keypairs as kp_policies
 
 
-ALIAS = 'os-keypairs'
-
-
 class KeypairController(wsgi.Controller):
 
     """Keypair API controller for the OpenStack API."""
@@ -323,37 +320,18 @@ class Controller(wsgi.Controller):
             self._add_key_name(req, servers)
 
 
-class Keypairs(extensions.V21APIExtensionBase):
-    """Keypair Support."""
+# NOTE(gmann): This function is not supposed to use 'body_deprecated_param'
+# parameter as this is placed to handle scheduler_hint extension for V2.1.
+def server_create(server_dict, create_kwargs, body_deprecated_param):
+    # NOTE(alex_xu): The v2.1 API compat mode, we strip the spaces for
+    # keypair create. But we didn't strip spaces at here for
+    # backward-compatible some users already created keypair and name with
+    # leading/trailing spaces by legacy v2 API.
+    create_kwargs['key_name'] = server_dict.get('key_name')
 
-    name = "Keypairs"
-    alias = ALIAS
-    version = 1
 
-    def get_resources(self):
-        resources = [
-            extensions.ResourceExtension(ALIAS,
-                                         KeypairController())]
-        return resources
-
-    def get_controller_extensions(self):
-        controller = Controller()
-        extension = extensions.ControllerExtension(self, 'servers', controller)
-        return [extension]
-
-    # use nova.api.extensions.server.extensions entry point to modify
-    # server create kwargs
-    # NOTE(gmann): This function is not supposed to use 'body_deprecated_param'
-    # parameter as this is placed to handle scheduler_hint extension for V2.1.
-    def server_create(self, server_dict, create_kwargs, body_deprecated_param):
-        # NOTE(alex_xu): The v2.1 API compat mode, we strip the spaces for
-        # keypair create. But we didn't strip spaces at here for
-        # backward-compatible some users already created keypair and name with
-        # leading/trailing spaces by legacy v2 API.
-        create_kwargs['key_name'] = server_dict.get('key_name')
-
-    def get_server_create_schema(self, version):
-        if version == '2.0':
-            return keypairs.server_create_v20
-        else:
-            return keypairs.server_create
+def get_server_create_schema(version):
+    if version == '2.0':
+        return keypairs.server_create_v20
+    else:
+        return keypairs.server_create
