@@ -24,17 +24,17 @@ from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import compute
 from nova import exception
-
-
-ALIAS = "os-multinic"
-authorize = extensions.os_compute_authorizer(ALIAS)
+from nova.policies import multinic as multinic_policies
 
 
 class MultinicController(wsgi.Controller):
+    """This API is deprecated from Microversion '2.44'."""
+
     def __init__(self, *args, **kwargs):
         super(MultinicController, self).__init__(*args, **kwargs)
-        self.compute_api = compute.API(skip_policy_check=True)
+        self.compute_api = compute.API()
 
+    @wsgi.Controller.api_version("2.1", "2.43")
     @wsgi.response(202)
     @wsgi.action('addFixedIp')
     @extensions.expected_errors((400, 404))
@@ -42,7 +42,7 @@ class MultinicController(wsgi.Controller):
     def _add_fixed_ip(self, req, id, body):
         """Adds an IP on a given network to an instance."""
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(multinic_policies.BASE_POLICY_NAME)
 
         instance = common.get_instance(self.compute_api, context, id)
         network_id = body['addFixedIp']['networkId']
@@ -53,6 +53,7 @@ class MultinicController(wsgi.Controller):
         except exception.NoMoreFixedIps as e:
             raise exc.HTTPBadRequest(explanation=e.format_message())
 
+    @wsgi.Controller.api_version("2.1", "2.43")
     @wsgi.response(202)
     @wsgi.action('removeFixedIp')
     @extensions.expected_errors((400, 404))
@@ -60,7 +61,7 @@ class MultinicController(wsgi.Controller):
     def _remove_fixed_ip(self, req, id, body):
         """Removes an IP from an instance."""
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(multinic_policies.BASE_POLICY_NAME)
 
         instance = common.get_instance(self.compute_api, context, id)
         address = body['removeFixedIp']['address']
@@ -71,21 +72,3 @@ class MultinicController(wsgi.Controller):
             raise exc.HTTPNotFound(explanation=e.format_message())
         except exception.FixedIpNotFoundForSpecificInstance as e:
             raise exc.HTTPBadRequest(explanation=e.format_message())
-
-
-# Note: The class name is as it has to be for this to be loaded as an
-# extension--only first character capitalized.
-class Multinic(extensions.V21APIExtensionBase):
-    """Multiple network support."""
-
-    name = "Multinic"
-    alias = ALIAS
-    version = 1
-
-    def get_controller_extensions(self):
-        controller = MultinicController()
-        extension = extensions.ControllerExtension(self, 'servers', controller)
-        return [extension]
-
-    def get_resources(self):
-        return []
