@@ -40,6 +40,14 @@ VERSIONS = [
     '1.3',  # Adds 'member_of' query parameter to get resource providers
             # that are members of any of the listed aggregates
     '1.4',  # Adds resources query string parameter in GET /resource_providers
+    '1.5',  # Adds DELETE /resource_providers/{uuid}/inventories
+    '1.6',  # Adds /traits and /resource_providers{uuid}/traits resource
+            # endpoints
+    '1.7',  # PUT /resource_classes/{name} is bodiless create or update
+    '1.8',  # Adds 'project_id' and 'user_id' required request parameters to
+            # PUT /allocations
+    '1.9',  # Adds GET /usages
+    '1.10',  # Adds GET /allocation_candidates resource endpoint
 ]
 
 
@@ -73,11 +81,26 @@ def parse_version_string(version_string):
             version_string, exc))
 
 
-def raise_404_if_not_version(req, min_version, max_version=None):
-    """Utility to raise a 404 if the wanted microversion does not match."""
+def raise_http_status_code_if_not_version(req, status_code, min_version,
+                                          max_version=None):
+    """Utility to raise a http status code if the wanted microversion does not
+       match.
+
+    :param req: The HTTP request for the placement api
+    :param status_code: HTTP status code (integer value) to be raised
+    :param min_version: Minimum placement microversion level
+    :param max_version: Maximum placement microversion level
+    :returns: None
+    :raises: HTTP status code if the specified microversion does not match
+    :raises: KeyError if status_code is not a valid HTTP status code
+    """
+    if not isinstance(min_version, tuple):
+        min_version = parse_version_string(min_version)
+    if max_version and not isinstance(max_version, tuple):
+        max_version = parse_version_string(max_version)
     want_version = req.environ[MICROVERSION_ENVIRON]
     if not want_version.matches(min_version, max_version):
-        raise webob.exc.HTTPNotFound
+        raise webob.exc.status_map[status_code]
 
 
 class MicroversionMiddleware(object):
@@ -131,9 +154,6 @@ class Version(collections.namedtuple('Version', 'major minor')):
     def __str__(self):
         return '%s.%s' % (self.major, self.minor)
 
-    def __float__(self):
-        return float(self.__str__())
-
     @property
     def max_version(self):
         if not self.MAX_VERSION:
@@ -202,7 +222,7 @@ def _fully_qualified_name(obj):
     return name
 
 
-def _find_method(f, version_float):
+def _find_method(f, version):
     """Look in VERSIONED_METHODS for method with right name matching version.
 
     If no match is found raise a 404.
@@ -212,7 +232,7 @@ def _find_method(f, version_float):
     # just in case.
     method_list = VERSIONED_METHODS.get(qualified_name, [])
     for min_version, max_version, func in method_list:
-        if min_version <= version_float <= max_version:
+        if min_version <= version <= max_version:
             return func
 
     raise webob.exc.HTTPNotFound()
@@ -234,18 +254,18 @@ def version_handler(min_ver, max_ver=None):
                     maximum version allowed for the decorated method.
     """
     def decorator(f):
-        min_version_float = float(min_ver)
+        min_version = parse_version_string(min_ver)
         if max_ver:
-            max_version_float = float(max_ver)
+            max_version = parse_version_string(max_ver)
         else:
-            max_version_float = float(max_version_string())
+            max_version = parse_version_string(max_version_string())
         qualified_name = _fully_qualified_name(f)
         VERSIONED_METHODS[qualified_name].append(
-            (min_version_float, max_version_float, f))
+            (min_version, max_version, f))
 
         def decorated_func(req, *args, **kwargs):
-            version_float = float(req.environ[MICROVERSION_ENVIRON])
-            return _find_method(f, version_float)(req, *args, **kwargs)
+            version = req.environ[MICROVERSION_ENVIRON]
+            return _find_method(f, version)(req, *args, **kwargs)
 
         # Sort highest min version to beginning of list.
         VERSIONED_METHODS[qualified_name].sort(key=lambda x: x[0],
