@@ -29,8 +29,6 @@ from nova.api.openstack import versioned_method
 from nova import exception
 from nova import i18n
 from nova.i18n import _
-from nova.i18n import _LE
-from nova.i18n import _LI
 from nova import utils
 from nova import wsgi
 
@@ -149,18 +147,6 @@ class Request(wsgi.Request):
     def get_db_flavor(self, flavorid):
         return self.get_db_item('flavors', flavorid)
 
-    def cache_db_compute_nodes(self, compute_nodes):
-        self.cache_db_items('compute_nodes', compute_nodes, 'id')
-
-    def cache_db_compute_node(self, compute_node):
-        self.cache_db_items('compute_nodes', [compute_node], 'id')
-
-    def get_db_compute_nodes(self):
-        return self.get_db_items('compute_nodes')
-
-    def get_db_compute_node(self, id):
-        return self.get_db_item('compute_nodes', id)
-
     def best_match_content_type(self):
         """Determine the requested response content-type."""
         if 'nova.best_content_type' not in self.environ:
@@ -421,14 +407,14 @@ class ResourceExceptionHandler(object):
                     explanation=ex_value.format_message()))
         elif isinstance(ex_value, TypeError):
             exc_info = (ex_type, ex_value, ex_traceback)
-            LOG.error(_LE('Exception handling resource: %s'), ex_value,
+            LOG.error('Exception handling resource: %s', ex_value,
                       exc_info=exc_info)
             raise Fault(webob.exc.HTTPBadRequest())
         elif isinstance(ex_value, Fault):
-            LOG.info(_LI("Fault thrown: %s"), ex_value)
+            LOG.info("Fault thrown: %s", ex_value)
             raise ex_value
         elif isinstance(ex_value, webob.exc.HTTPException):
-            LOG.info(_LI("HTTP exception thrown: %s"), ex_value)
+            LOG.info("HTTP exception thrown: %s", ex_value)
             raise Fault(ex_value)
 
         # We didn't handle the exception
@@ -627,13 +613,7 @@ class Resource(wsgi.Application):
 
         # Now, deserialize the request body...
         try:
-            contents = {}
-            if self._should_have_body(request):
-                # allow empty body with PUT and POST
-                if request.content_length == 0:
-                    contents = {'body': None}
-                else:
-                    contents = self.deserialize(body)
+            contents = self._get_request_content(body, request)
         except exception.MalformedRequestBody:
             msg = _("Malformed request body")
             return Fault(webob.exc.HTTPBadRequest(explanation=msg))
@@ -701,6 +681,16 @@ class Resource(wsgi.Application):
 
         return response
 
+    def _get_request_content(self, body, request):
+        contents = {}
+        if self._should_have_body(request):
+            # allow empty body with PUT and POST
+            if request.content_length == 0 or request.content_length is None:
+                contents = {'body': None}
+            else:
+                contents = self.deserialize(body)
+        return contents
+
     def get_method(self, request, action, content_type, body):
         meth, extensions = self._get_method(request,
                                             action,
