@@ -17,7 +17,7 @@ import re
 
 from oslo_log import log as logging
 from oslo_utils import strutils
-import six
+
 
 import nova.conf
 from nova import exception
@@ -48,7 +48,7 @@ bdm_new_fields = set(['source_type', 'destination_type',
                      'connection_info', 'tag'])
 
 
-bdm_db_only_fields = set(['id', 'instance_uuid'])
+bdm_db_only_fields = set(['id', 'instance_uuid', 'attachment_id'])
 
 
 bdm_db_inherited_fields = set(['created_at', 'updated_at',
@@ -89,11 +89,11 @@ class BlockDeviceDict(dict):
             bdm_dict.get('delete_on_termination'))
         # NOTE (ndipanov): Never default db fields
         self.update({field: None for field in self._fields - do_not_default})
-        self.update(list(six.iteritems(bdm_dict)))
+        self.update(bdm_dict.items())
 
     def _validate(self, bdm_dict):
         """Basic data format validations."""
-        dict_fields = set(key for key, _ in six.iteritems(bdm_dict))
+        dict_fields = set(key for key, _ in bdm_dict.items())
 
         # Check that there are no bogus fields
         if not (dict_fields <=
@@ -139,7 +139,7 @@ class BlockDeviceDict(dict):
         non_computable_fields = set(['boot_index', 'disk_bus',
                                      'guest_format', 'device_type'])
 
-        new_bdm = {fld: val for fld, val in six.iteritems(legacy_bdm)
+        new_bdm = {fld: val for fld, val in legacy_bdm.items()
                    if fld in copy_over_fields}
 
         virt_name = legacy_bdm.get('virtual_name')
@@ -184,10 +184,7 @@ class BlockDeviceDict(dict):
             device_uuid = api_dict.get('uuid')
             destination_type = api_dict.get('destination_type')
 
-            if source_type not in ('volume', 'image', 'snapshot', 'blank'):
-                raise exception.InvalidBDMFormat(
-                    details=_("Invalid source_type field."))
-            elif source_type == 'blank' and device_uuid:
+            if source_type == 'blank' and device_uuid:
                 raise exception.InvalidBDMFormat(
                     details=_("Invalid device UUID."))
             elif source_type != 'blank':
@@ -196,17 +193,14 @@ class BlockDeviceDict(dict):
                         details=_("Missing device UUID."))
                 api_dict[source_type + '_id'] = device_uuid
             if source_type == 'image' and destination_type == 'local':
-                try:
-                    # NOTE(mriedem): boot_index can be None so we need to
-                    # account for that to avoid a TypeError.
-                    boot_index = api_dict.get('boot_index', -1)
-                    if boot_index is None:
-                        # boot_index=None is equivalent to -1.
-                        boot_index = -1
-                    boot_index = int(boot_index)
-                except ValueError:
-                    raise exception.InvalidBDMFormat(
-                        details=_("Boot index is invalid."))
+                # NOTE(mriedem): boot_index can be None so we need to
+                # account for that to avoid a TypeError.
+                boot_index = api_dict.get('boot_index', -1)
+                if boot_index is None:
+                    # boot_index=None is equivalent to -1.
+                    boot_index = -1
+                boot_index = int(boot_index)
+
                 # if this bdm is generated from --image ,then
                 # source_type = image and destination_type = local is allowed
                 if not (image_uuid_specified and boot_index == 0):
@@ -375,7 +369,7 @@ def from_legacy_mapping(legacy_block_device_mapping, image_uuid='',
 
 
 def properties_root_device_name(properties):
-    """get root device name from image meta data.
+    """Get root device name from image meta data.
     If it isn't specified, return None.
     """
     root_device_name = None
@@ -397,7 +391,7 @@ def validate_device_name(value):
     try:
         # NOTE (ndipanov): Do not allow empty device names
         #                  until assigning default values
-        #                  is supported by nova.compute
+        #                  are supported by nova.compute
         utils.check_string_length(value, 'Device name',
                                   min_length=1, max_length=255)
     except exception.InvalidInput:
@@ -416,7 +410,7 @@ def validate_and_default_volume_size(bdm):
                 bdm['volume_size'], 'volume_size', min_value=0)
         except exception.InvalidInput:
             # NOTE: We can remove this validation code after removing
-            # Nova v2.0 API code because v2.1 API validates this case
+            # Nova v2.0 API code, because v2.1 API validates this case
             # already at its REST API layer.
             raise exception.InvalidBDMFormat(
                 details=_("Invalid volume_size."))
@@ -547,7 +541,9 @@ def instance_block_mapping(instance, bdms):
     #                 Right now sort by device name for deterministic
     #                 result.
     if ebs_devices:
-        ebs_devices.sort()
+        # NOTE(claudiub): python2.7 sort places None values first.
+        # this sort will maintain the same behaviour for both py27 and py34.
+        ebs_devices = sorted(ebs_devices, key=lambda x: (x is not None, x))
         for nebs, ebs in enumerate(ebs_devices):
             mappings['ebs%d' % nebs] = ebs
 
