@@ -27,12 +27,6 @@ from oslo_config import types
 
 from nova.conf import paths
 
-# Downtime period in milliseconds
-LIVE_MIGRATION_DOWNTIME_MIN = 100
-# Step count
-LIVE_MIGRATION_DOWNTIME_STEPS_MIN = 3
-# Delay in seconds
-LIVE_MIGRATION_DOWNTIME_DELAY_MIN = 10
 
 libvirt_group = cfg.OptGroup("libvirt",
                              title="Libvirt Options",
@@ -257,9 +251,12 @@ management network.
 Possible values:
 
 * A valid IP address or hostname, else None.
+
+Related options:
+
+* ``live_migration_tunnelled``: The live_migration_inbound_addr value is
+  ignored if tunneling is enabled.
 """),
-    # TODO(hieulq): change to URIOpt for validating schemas with next release
-    # of oslo_config.
     cfg.StrOpt('live_migration_uri',
                deprecated_for_removal=True,
                deprecated_since="15.0.0",
@@ -276,29 +273,34 @@ on virt_type). Any included "%s" is replaced with the migration target
 hostname.
 
 If this option is set to None (which is the default), Nova will automatically
-generate the `live_migration_uri` value based on only 3 supported `virt_type`
+generate the `live_migration_uri` value based on only 4 supported `virt_type`
 in following list:
+
 * 'kvm': 'qemu+tcp://%s/system'
 * 'qemu': 'qemu+tcp://%s/system'
 * 'xen': 'xenmigr://%s/system'
+* 'parallels': 'parallels+tcp://%s/system'
 
 Related options:
+
 * ``live_migration_inbound_addr``: If ``live_migration_inbound_addr`` value
-  is not None, the ip/hostname address of target compute node is used instead
-  of ``live_migration_uri`` as the uri for live migration.
+  is not None and ``live_migration_tunnelled`` is False, the ip/hostname
+  address of target compute node is used instead of ``live_migration_uri`` as
+  the uri for live migration.
 * ``live_migration_scheme``: If ``live_migration_uri`` is not set, the scheme
   used for live migration is taken from ``live_migration_scheme`` instead.
 """),
     cfg.StrOpt('live_migration_scheme',
                help="""
-Schema used for live migration.
+URI scheme used for live migration.
 
-Override the default libvirt live migration scheme (which is dependant on
+Override the default libvirt live migration scheme (which is dependent on
 virt_type). If this option is set to None, nova will automatically choose a
 sensible default based on the hypervisor. It is not recommended that you change
 this unless you are very sure that hypervisor supports a particular scheme.
 
 Related options:
+
 * ``virt_type``: This option is meaningful only when ``virt_type`` is set to
   `kvm` or `qemu`.
 * ``live_migration_uri``: If ``live_migration_uri`` value is not None, the
@@ -315,15 +317,15 @@ VIR_MIGRATE_TUNNELLED migration flag, avoiding the need to configure
 the network to allow direct hypervisor to hypervisor communication.
 If False, use the native transport. If not set, Nova will choose a
 sensible default based on, for example the availability of native
-encryption support in the hypervisor. Enable this option will definitely
+encryption support in the hypervisor. Enabling this option will definitely
 impact performance massively.
 
 Note that this option is NOT compatible with use of block migration.
 
-Possible values:
+Related options:
 
-* Supersedes and (if set) overrides the deprecated 'live_migration_flag' and
-  'block_migration_flag' to enable tunneled migration.
+* ``live_migration_inbound_addr``: The live_migration_inbound_addr value is
+  ignored if tunneling is enabled.
 """),
     cfg.IntOpt('live_migration_bandwidth',
                default=0,
@@ -334,15 +336,14 @@ If set to 0, the hypervisor will choose a suitable default. Some hypervisors
 do not support this feature and will return an error if bandwidth is not 0.
 Please refer to the libvirt documentation for further details.
 """),
-    # TODO(hieulq): Need to add min argument by moving from
-    # LIVE_MIGRATION_DOWNTIME_MIN constant.
     cfg.IntOpt('live_migration_downtime',
                default=500,
+               min=100,
                help="""
 Maximum permitted downtime, in milliseconds, for live migration
 switchover.
 
-Will be rounded up to a minimum of %dms. You can increase this value
+Will be rounded up to a minimum of 100ms. You can increase this value
 if you want to allow live-migrations to complete faster, or avoid
 live-migration timeout errors by allowing the guest to be paused for
 longer during the live-migration switch over.
@@ -350,27 +351,25 @@ longer during the live-migration switch over.
 Related options:
 
 * live_migration_completion_timeout
-""" % LIVE_MIGRATION_DOWNTIME_MIN),
-    # TODO(hieulq): Need to add min argument by moving from
-    # LIVE_MIGRATION_DOWNTIME_STEPS_MIN constant.
+"""),
     cfg.IntOpt('live_migration_downtime_steps',
                default=10,
+               min=3,
                help="""
 Number of incremental steps to reach max downtime value.
 
-Will be rounded up to a minimum of %d steps.
-""" % LIVE_MIGRATION_DOWNTIME_STEPS_MIN),
-    # TODO(hieulq): Need to add min argument by moving from
-    # LIVE_MIGRATION_DOWNTIME_DELAY_MIN constant.
+Will be rounded up to a minimum of 3 steps.
+"""),
     cfg.IntOpt('live_migration_downtime_delay',
                default=75,
+               min=3,
                help="""
 Time to wait, in seconds, between each step increase of the migration
 downtime.
 
-Minimum delay is %d seconds. Value is per GiB of guest RAM + disk to be
+Minimum delay is 3 seconds. Value is per GiB of guest RAM + disk to be
 transferred, with lower bound of a minimum of 2 GiB per device.
-""" % LIVE_MIGRATION_DOWNTIME_DELAY_MIN),
+"""),
     cfg.IntOpt('live_migration_completion_timeout',
                default=800,
                mutable=True,
@@ -435,8 +434,7 @@ This option allows nova to start live migration with auto converge on.
 Auto converge throttles down CPU if a progress of on-going live migration
 is slow. Auto converge will only be used if this flag is set to True and
 post copy is not permitted or post copy is unavailable due to the version
-of libvirt and QEMU in use. Auto converge requires libvirt>=1.2.3 and
-QEMU>=1.6.0.
+of libvirt and QEMU in use.
 
 Related options:
 
@@ -520,7 +518,7 @@ Related options:
     cfg.ListOpt(
         'cpu_model_extra_flags',
         item_type=types.String(
-            choices=['pcid', 'ssbd', 'virt-ssbd'],
+            choices=['pcid'],
             ignore_case=True,
         ),
         default=[],
@@ -535,16 +533,13 @@ virtual CPU model::
     cpu_model = IvyBridge
     cpu_model_extra_flags = pcid
 
-Currently, the choice is restricted to a few options: ``pcid``,
-``ssbd``, and ``virt-ssbd`` (the options are case-insensitive, so
-``PCID`` is also valid, for example).  These flags are now required to
-address the guest performance degradation as a result of applying the
-"Meltdown" CVE fixes (``pcid``) and exposure mitigation (``ssbd`` and
-``virt-ssbd``) on affected CPU models.
+Currently, the choice is restricted to only one option: ``pcid`` (the
+option is case-insensitive, so ``PCID`` is also valid).  This flag is
+now required to address the guest performance degradation as a result of
+applying the "Meltdown" CVE fixes on certain Intel CPU models.
 
-Note that when using this config attribute to set the 'PCID' and
-related CPU flags, not all virtual (i.e. libvirt / QEMU) CPU models
-need it:
+Note that when using this config attribute to set the 'PCID' CPU flag,
+not all virtual (i.e. libvirt / QEMU) CPU models need it:
 
 * The only virtual CPU models that include the 'PCID' capability are
   Intel "Haswell", "Broadwell", and "Skylake" variants.
@@ -554,13 +549,6 @@ need it:
   even if the host CPUs by the same name include it.  I.e.  'PCID' needs
   to be explicitly specified when using the said virtual CPU models.
 
-For more information about ``ssbd`` and ``virt-ssbd`` applicability,
-please refer to the following security updates:
-
-https://www.us-cert.gov/ncas/alerts/TA18-141A
-
-https://www.redhat.com/archives/libvir-list/2018-May/msg01562.html
-
 For now, the ``cpu_model_extra_flags`` config attribute is valid only in
 combination with ``cpu_mode`` + ``cpu_model`` options.
 
@@ -588,8 +576,55 @@ Related options:
                help='Location where the Xen hvmloader is kept'),
     cfg.ListOpt('disk_cachemodes',
                 default=[],
-                help='Specific cachemodes to use for different disk types '
-                     'e.g: file=directsync,block=none'),
+                help="""
+Specific cache modes to use for different disk types.
+
+For example: file=directsync,block=none,network=writeback
+
+For local or direct-attached storage, it is recommended that you use
+writethrough (default) mode, as it ensures data integrity and has acceptable
+I/O performance for applications running in the guest, especially for read
+operations. However, caching mode none is recommended for remote NFS storage,
+because direct I/O operations (O_DIRECT) perform better than synchronous I/O
+operations (with O_SYNC). Caching mode none effectively turns all guest I/O
+operations into direct I/O operations on the host, which is the NFS client in
+this environment.
+
+Possible cache modes:
+
+* default: Same as writethrough.
+* none: With caching mode set to none, the host page cache is disabled, but
+  the disk write cache is enabled for the guest. In this mode, the write
+  performance in the guest is optimal because write operations bypass the host
+  page cache and go directly to the disk write cache. If the disk write cache
+  is battery-backed, or if the applications or storage stack in the guest
+  transfer data properly (either through fsync operations or file system
+  barriers), then data integrity can be ensured. However, because the host
+  page cache is disabled, the read performance in the guest would not be as
+  good as in the modes where the host page cache is enabled, such as
+  writethrough mode.
+* writethrough: writethrough mode is the default caching mode. With
+  caching set to writethrough mode, the host page cache is enabled, but the
+  disk write cache is disabled for the guest. Consequently, this caching mode
+  ensures data integrity even if the applications and storage stack in the
+  guest do not transfer data to permanent storage properly (either through
+  fsync operations or file system barriers). Because the host page cache is
+  enabled in this mode, the read performance for applications running in the
+  guest is generally better. However, the write performance might be reduced
+  because the disk write cache is disabled.
+* writeback: With caching set to writeback mode, both the host page cache
+  and the disk write cache are enabled for the guest. Because of this, the
+  I/O performance for applications running in the guest is good, but the data
+  is not protected in a power failure. As a result, this caching mode is
+  recommended only for temporary data where potential data loss is not a
+  concern.
+* directsync: Like "writethrough", but it bypasses the host page cache.
+* unsafe: Caching mode of unsafe ignores cache transfer operations
+  completely. As its name implies, this caching mode should be used only for
+  temporary data where data loss is not a concern. This mode can be useful for
+  speeding up guest installations, but you should switch to another caching
+  mode in production environments.
+"""),
     cfg.StrOpt('rng_dev_path',
                help='A path to a device that will be used as source of '
                     'entropy on the host. Permitted options are: '
@@ -788,19 +823,6 @@ libvirt_vif_opts = [
 ]
 
 libvirt_volume_opts = [
-    cfg.ListOpt('qemu_allowed_storage_drivers',
-                default=[],
-                help="""
-Protocols listed here will be accessed directly from QEMU.
-
-If gluster is present in qemu_allowed_storage_drivers, glusterfs's backend will
-pass a disk configuration to QEMU. This allows QEMU to access the volume using
-libgfapi rather than mounting GlusterFS via fuse.
-
-Possible values:
-
-* [gluster]
-"""),
     cfg.BoolOpt('volume_use_multipath',
                 default=False,
                 deprecated_name='iscsi_use_multipath',
@@ -809,7 +831,13 @@ Use multipath connection of the iSCSI or FC volume
 
 Volumes can be connected in the LibVirt as multipath devices. This will
 provide high availability and fault tolerance.
-""")
+"""),
+    cfg.IntOpt('num_volume_scan_tries',
+               deprecated_name='num_iscsi_scan_tries',
+               default=5,
+               help="""
+Number of times to scan given storage protocol to find volume.
+"""),
 ]
 
 libvirt_volume_aoe_opts = [
@@ -824,24 +852,7 @@ attempts that can be made to discover the AoE device.
 """)
 ]
 
-libvirt_volume_glusterfs_opts = [
-    cfg.StrOpt('glusterfs_mount_point_base',
-               default=paths.state_path_def('mnt'),
-               help="""
-Absolute path to the directory where the glusterfs volume is mounted on the
-compute node.
-""")
-]
-
-# TODO(sneti): This config option is also used for other protocols like
-# fibrechannel, scaleio, disco. So this should be renamed to
-# num_volume_scan_tries
 libvirt_volume_iscsi_opts = [
-    cfg.IntOpt('num_iscsi_scan_tries',
-               default=5,
-               help="""
-Number of times to scan iSCSI target to find volume.
-"""),
     cfg.StrOpt('iscsi_iface',
                deprecated_name='iscsi_transport',
                help="""
@@ -939,31 +950,6 @@ Possible values:
                help='Path to a Quobyte Client configuration file.'),
 ]
 
-libvirt_volume_scality_opts = [
-    cfg.StrOpt('scality_sofs_config',
-               help="""
-Path or URL to Scality SOFS(Scale-Out File Server) configuration file.
-
-The Scality SOFS provides OpenStack users the option of storing their
-data on a high capacity, replicated, highly available Scality Ring object
-storage cluster.
-"""),
-    cfg.StrOpt('scality_sofs_mount_point',
-               default='$state_path/scality',
-               help="""
-Base dir where Scality SOFS shall be mounted.
-
-The Scality volume driver in Nova mounts SOFS and lets the hypervisor access
-the volumes.
-
-Possible values:
-
-* $state_path/scality where state_path is a config option that specifies
-  the top-level directory for maintaining nova's state or Any string
-  containing the full directory path.
-"""),
-]
-
 libvirt_volume_smbfs_opts = [
     cfg.StrOpt('smbfs_mount_point_base',
                default=paths.state_path_def('mnt'),
@@ -1052,7 +1038,7 @@ Related options:
 """
               ),
     cfg.StrOpt('vzstorage_log_path',
-               default='/var/log/pstorage/%(cluster_name)s/nova.log.gz',
+               default='/var/log/vstorage/%(cluster_name)s/nova.log.gz',
                help="""
 Path to vzstorage client log.
 
@@ -1117,13 +1103,11 @@ ALL_OPTS = list(itertools.chain(
     libvirt_vif_opts,
     libvirt_volume_opts,
     libvirt_volume_aoe_opts,
-    libvirt_volume_glusterfs_opts,
     libvirt_volume_iscsi_opts,
     libvirt_volume_iser_opts,
     libvirt_volume_net_opts,
     libvirt_volume_nfs_opts,
     libvirt_volume_quobyte_opts,
-    libvirt_volume_scality_opts,
     libvirt_volume_smbfs_opts,
     libvirt_remotefs_opts,
     libvirt_volume_vzstorage_opts,
