@@ -301,7 +301,7 @@ class API(base_api.NetworkAPI):
     # NOTE(danms): Here for neutron compatibility
     def allocate_port_for_instance(self, context, instance, port_id,
                                    network_id=None, requested_ip=None,
-                                   bind_host_id=None):
+                                   bind_host_id=None, tag=None):
         raise NotImplementedError()
 
     # NOTE(danms): Here for neutron compatibility
@@ -365,11 +365,6 @@ class API(base_api.NetworkAPI):
                 objects.Network.associate(context, project,
                                           network_id=network.id, force=True)
 
-    def get_instance_nw_info(self, context, instance, **kwargs):
-        """Returns all network info related to an instance."""
-        return super(API, self).get_instance_nw_info(context, instance,
-                                                     **kwargs)
-
     def _get_instance_nw_info(self, context, instance, **kwargs):
         """Returns all network info related to an instance."""
         flavor = instance.get_flavor()
@@ -525,8 +520,7 @@ class API(base_api.NetworkAPI):
 
         self.network_rpcapi.migrate_instance_finish(context, **args)
 
-    def setup_instance_network_on_host(self, context, instance, host,
-                                       migration=None):
+    def setup_instance_network_on_host(self, context, instance, host):
         """Setup network for specified instance on host."""
         self.migrate_instance_finish(context, instance,
                                      {'source_compute': None,
