@@ -798,17 +798,13 @@ class NetworkManager(manager.Manager):
         quota_project, quota_user = quotas_obj.ids_from_instance(context,
                                                                  instance)
         try:
-            quotas.reserve(fixed_ips=1, project_id=quota_project,
-                           user_id=quota_user)
-            cleanup.append(functools.partial(quotas.rollback, context))
+            quotas.check_deltas(context, {'fixed_ips': 1}, quota_project)
         except exception.OverQuota as exc:
-            usages = exc.kwargs['usages']
-            used = (usages['fixed_ips']['in_use'] +
-                    usages['fixed_ips']['reserved'])
+            count = exc.kwargs['usages']['fixed_ips']
             LOG.warning(_LW("Quota exceeded for project %(pid)s, tried to "
                             "allocate fixed IP. %(used)s of %(allowed)s are "
                             "in use or are already reserved."),
-                        {'pid': quota_project, 'used': used,
+                        {'pid': quota_project, 'used': count,
                          'allowed': exc.kwargs['quotas']['fixed_ips']},
                         instance_uuid=instance_id)
             raise exception.FixedIpLimitExceeded()
@@ -855,6 +851,29 @@ class NetworkManager(manager.Manager):
 
                 cleanup.append(functools.partial(fip.disassociate, context))
 
+                # NOTE(melwitt): We recheck the quota after creating the object
+                # to prevent users from allocating more resources than their
+                # allowed quota in the event of a race. This is configurable
+                # because it can be expensive if strict quota limits are not
+                # required in a deployment.
+                if CONF.quota.recheck_quota:
+                    try:
+                        quotas.check_deltas(context, {'fixed_ips': 0},
+                                            quota_project)
+                    except exception.OverQuota as exc:
+                        # Cleanup of the fixed IP allocation occurs in the
+                        # outermost catch-all except block.
+                        count = exc.kwargs['usages']['fixed_ips']
+                        allowed = exc.kwargs['quotas']['fixed_ips']
+                        LOG.warning(_LW("Quota exceeded for project %(pid)s, "
+                                        "tried to allocate fixed IP. %(used)s "
+                                        "of %(allowed)s are in use or are "
+                                        "already reserved."),
+                                    {'pid': quota_project, 'used': count,
+                                     'allowed': allowed},
+                                    instance_uuid=instance_id)
+                        raise exception.FixedIpLimitExceeded()
+
                 LOG.debug('Refreshing security group members for instance.',
                           instance=instance)
                 self._do_trigger_security_group_members_refresh_for_instance(
@@ -887,7 +906,6 @@ class NetworkManager(manager.Manager):
                     self._teardown_network_on_host,
                     context, network))
 
-            quotas.commit()
             if address is None:
                 # TODO(mriedem): should _setup_network_on_host return the addr?
                 LOG.debug('Fixed IP is setup on network %s but not returning '
@@ -927,101 +945,79 @@ class NetworkManager(manager.Manager):
             instance = objects.Instance.get_by_uuid(
                 context.elevated(read_deleted='yes'), instance_uuid)
 
-        quotas = self.quotas_cls(context=context)
-        quota_project, quota_user = quotas_obj.ids_from_instance(context,
-                                                                 instance)
-        try:
-            quotas.reserve(fixed_ips=-1, project_id=quota_project,
-                           user_id=quota_user)
-        except Exception:
-            LOG.exception(_LE("Failed to update usages deallocating "
-                              "fixed IP"))
+        self._do_trigger_security_group_members_refresh_for_instance(
+            instance_uuid)
 
-        try:
-            self._do_trigger_security_group_members_refresh_for_instance(
-                instance_uuid)
+        if self._validate_instance_zone_for_dns_domain(context, instance):
+            for n in self.instance_dns_manager.get_entries_by_address(
+                address, self.instance_dns_domain):
+                self.instance_dns_manager.delete_entry(n,
+                    self.instance_dns_domain)
 
-            if self._validate_instance_zone_for_dns_domain(context, instance):
-                for n in self.instance_dns_manager.get_entries_by_address(
-                    address, self.instance_dns_domain):
-                    self.instance_dns_manager.delete_entry(n,
-                        self.instance_dns_domain)
+        fixed_ip_ref.allocated = False
+        fixed_ip_ref.save()
 
-            fixed_ip_ref.allocated = False
-            fixed_ip_ref.save()
+        if teardown:
+            network = fixed_ip_ref.network
 
-            if teardown:
-                network = fixed_ip_ref.network
+            if CONF.force_dhcp_release:
+                dev = self.driver.get_dev(network)
+                # NOTE(vish): The below errors should never happen, but
+                #             there may be a race condition that is causing
+                #             them per
+                #             https://code.launchpad.net/bugs/968457,
+                #             so we log a message to help track down
+                #             the possible race.
+                if not vif_id:
+                    LOG.info(_LI("Unable to release %s because vif "
+                                 "doesn't exist"), address)
+                    return
 
-                if CONF.force_dhcp_release:
-                    dev = self.driver.get_dev(network)
-                    # NOTE(vish): The below errors should never happen, but
-                    #             there may be a race condition that is causing
-                    #             them per
-                    #             https://code.launchpad.net/bugs/968457,
-                    #             so we log a message to help track down
-                    #             the possible race.
-                    if not vif_id:
-                        LOG.info(_LI("Unable to release %s because vif "
-                                     "doesn't exist"), address)
-                        return
+                vif = objects.VirtualInterface.get_by_id(context, vif_id)
 
-                    vif = objects.VirtualInterface.get_by_id(context, vif_id)
+                if not vif:
+                    LOG.info(_LI("Unable to release %s because vif "
+                                 "object doesn't exist"), address)
+                    return
 
-                    if not vif:
-                        LOG.info(_LI("Unable to release %s because vif "
-                                     "object doesn't exist"), address)
-                        return
-
-                    # NOTE(cfb): Call teardown before release_dhcp to ensure
-                    #            that the IP can't be re-leased after a release
-                    #            packet is sent.
-                    self._teardown_network_on_host(context, network)
-                    # NOTE(vish): This forces a packet so that the
-                    #             release_fixed_ip callback will
-                    #             get called by nova-dhcpbridge.
-                    try:
-                        self.network_rpcapi.release_dhcp(context,
-                                                         instance.launched_on,
-                                                         dev, address,
-                                                         vif.address)
-                    except exception.RPCPinnedToOldVersion:
-                        # Fall back on previous behaviour of calling
-                        # release_dhcp on the local driver
-                        self.driver.release_dhcp(dev, address, vif.address)
-                    except exception.NetworkDhcpReleaseFailed:
-                        LOG.error(_LE("Error releasing DHCP for IP %(address)s"
-                                      " with MAC %(mac_address)s"),
-                                  {'address': address,
-                                   'mac_address': vif.address},
-                                  instance=instance)
-
-                    # NOTE(yufang521247): This is probably a failed dhcp fixed
-                    # ip. DHCPRELEASE packet sent to dnsmasq would not trigger
-                    # dhcp-bridge to run. Thus it is better to disassociate
-                    # such fixed ip here.
-                    fixed_ip_ref = objects.FixedIP.get_by_address(
-                        context, address)
-                    if (instance_uuid == fixed_ip_ref.instance_uuid and
-                            not fixed_ip_ref.leased):
-                        LOG.debug('Explicitly disassociating fixed IP %s from '
-                                  'instance.', address,
-                                  instance_uuid=instance_uuid)
-                        fixed_ip_ref.disassociate()
-                else:
-                    # We can't try to free the IP address so just call teardown
-                    self._teardown_network_on_host(context, network)
-        except Exception:
-            with excutils.save_and_reraise_exception():
+                # NOTE(cfb): Call teardown before release_dhcp to ensure
+                #            that the IP can't be re-leased after a release
+                #            packet is sent.
+                self._teardown_network_on_host(context, network)
+                # NOTE(vish): This forces a packet so that the
+                #             release_fixed_ip callback will
+                #             get called by nova-dhcpbridge.
                 try:
-                    quotas.rollback()
-                except Exception:
-                    LOG.warning(_LW("Failed to rollback quota for "
-                                    "deallocate fixed IP: %s"), address,
-                                instance=instance)
+                    self.network_rpcapi.release_dhcp(context,
+                                                     instance.launched_on,
+                                                     dev, address,
+                                                     vif.address)
+                except exception.RPCPinnedToOldVersion:
+                    # Fall back on previous behaviour of calling
+                    # release_dhcp on the local driver
+                    self.driver.release_dhcp(dev, address, vif.address)
+                except exception.NetworkDhcpReleaseFailed:
+                    LOG.error(_LE("Error releasing DHCP for IP %(address)s"
+                                  " with MAC %(mac_address)s"),
+                              {'address': address,
+                               'mac_address': vif.address},
+                              instance=instance)
 
-        # Commit the reservations
-        quotas.commit()
+                # NOTE(yufang521247): This is probably a failed dhcp fixed
+                # ip. DHCPRELEASE packet sent to dnsmasq would not trigger
+                # dhcp-bridge to run. Thus it is better to disassociate
+                # such fixed ip here.
+                fixed_ip_ref = objects.FixedIP.get_by_address(
+                    context, address)
+                if (instance_uuid == fixed_ip_ref.instance_uuid and
+                        not fixed_ip_ref.leased):
+                    LOG.debug('Explicitly disassociating fixed IP %s from '
+                              'instance.', address,
+                              instance_uuid=instance_uuid)
+                    fixed_ip_ref.disassociate()
+            else:
+                # We can't try to free the IP address so just call teardown
+                self._teardown_network_on_host(context, network)
 
     def release_dhcp(self, context, dev, address, vif_address):
         self.driver.release_dhcp(dev, address, vif_address)
