@@ -10,11 +10,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import nova.conf
 from nova.notifications.objects import base
+from nova.notifications.objects import flavor as flavor_payload
+from nova.notifications.objects import keypair as keypair_payload
 from nova.objects import base as nova_base
 from nova.objects import fields
 
 
+CONF = nova.conf.CONF
+
+
 @nova_base.NovaObjectRegistry.register_notification
 class InstancePayload(base.NotificationPayloadBase):
     SCHEMA = {
@@ -33,6 +39,8 @@ class InstancePayload(base.NotificationPayloadBase):
 
         'image_uuid': ('instance', 'image_ref'),
 
+        'key_name': ('instance', 'key_name'),
+
         'kernel_id': ('instance', 'kernel_id'),
         'ramdisk_id': ('instance', 'ramdisk_id'),
 
@@ -40,6 +48,7 @@ class InstancePayload(base.NotificationPayloadBase):
         'launched_at': ('instance', 'launched_at'),
         'terminated_at': ('instance', 'terminated_at'),
         'deleted_at': ('instance', 'deleted_at'),
+        'updated_at': ('instance', 'updated_at'),
 
         'state': ('instance', 'vm_state'),
         'power_state': ('instance', 'power_state'),
@@ -48,10 +57,15 @@ class InstancePayload(base.NotificationPayloadBase):
 
         'metadata': ('instance', 'metadata'),
         'locked': ('instance', 'locked'),
+        'auto_disk_config': ('instance', 'auto_disk_config')
     }
     # Version 1.0: Initial version
     # Version 1.1: add locked and display_description field
-    VERSION = '1.1'
+    # Version 1.2: Add auto_disk_config field
+    # Version 1.3: Add key_name field
+    # Version 1.4: Add BDM related data
+    # Version 1.5: Add updated_at field
+    VERSION = '1.5'
     fields = {
         'uuid': fields.UUIDField(),
         'user_id': fields.StringField(nullable=True),
@@ -69,6 +83,8 @@ class InstancePayload(base.NotificationPayloadBase):
         'flavor': fields.ObjectField('FlavorPayload'),
         'image_uuid': fields.StringField(nullable=True),
 
+        'key_name': fields.StringField(nullable=True),
+
         'kernel_id': fields.StringField(nullable=True),
         'ramdisk_id': fields.StringField(nullable=True),
 
@@ -76,6 +92,7 @@ class InstancePayload(base.NotificationPayloadBase):
         'launched_at': fields.DateTimeField(nullable=True),
         'terminated_at': fields.DateTimeField(nullable=True),
         'deleted_at': fields.DateTimeField(nullable=True),
+        'updated_at': fields.DateTimeField(nullable=True),
 
         'state': fields.InstanceStateField(nullable=True),
         'power_state': fields.InstancePowerStateField(nullable=True),
@@ -83,13 +100,23 @@ class InstancePayload(base.NotificationPayloadBase):
         'progress': fields.IntegerField(nullable=True),
 
         'ip_addresses': fields.ListOfObjectsField('IpPayload'),
+        'block_devices': fields.ListOfObjectsField('BlockDevicePayload',
+                                                   nullable=True),
 
         'metadata': fields.DictOfStringsField(),
         'locked': fields.BooleanField(),
+        'auto_disk_config': fields.DiskConfigField()
     }
 
-    def __init__(self, instance, **kwargs):
-        super(InstancePayload, self).__init__(**kwargs)
+    def __init__(self, instance):
+        super(InstancePayload, self).__init__()
+        network_info = instance.get_network_info()
+        self.ip_addresses = IpPayload.from_network_info(network_info)
+        self.flavor = flavor_payload.FlavorPayload(flavor=instance.flavor)
+        # TODO(gibi): investigate the possibility to use already in scope bdm
+        # when available like in instance.create
+        self.block_devices = BlockDevicePayload.from_instance(instance)
+
         self.populate_schema(instance=instance)
 
 
@@ -98,18 +125,37 @@ class InstanceActionPayload(InstancePayload):
     # No SCHEMA as all the additional fields are calculated
 
     # Version 1.1: locked and display_description added to InstancePayload
-    VERSION = '1.1'
+    # Version 1.2: Added auto_disk_config field to InstancePayload
+    # Version 1.3: Added key_name field to InstancePayload
+    # Version 1.4: Add BDM related data
+    # Version 1.5: Added updated_at field to InstancePayload
+    VERSION = '1.5'
     fields = {
         'fault': fields.ObjectField('ExceptionPayload', nullable=True),
     }
 
-    def __init__(self, instance, fault, ip_addresses, flavor, **kwargs):
-        super(InstanceActionPayload, self).__init__(
+    def __init__(self, instance, fault):
+        super(InstanceActionPayload, self).__init__(instance=instance)
+        self.fault = fault
+
+
+@nova_base.NovaObjectRegistry.register_notification
+class InstanceActionVolumePayload(InstanceActionPayload):
+    # Version 1.0: Initial version
+    # Version 1.1: Added key_name field to InstancePayload
+    # Version 1.2: Add BDM related data
+    # Version 1.3: Added updated_at field to InstancePayload
+
+    VERSION = '1.3'
+    fields = {
+        'volume_id': fields.UUIDField()
+    }
+
+    def __init__(self, instance, fault, volume_id):
+        super(InstanceActionVolumePayload, self).__init__(
                 instance=instance,
-                fault=fault,
-                ip_addresses=ip_addresses,
-                flavor=flavor,
-                **kwargs)
+                fault=fault)
+        self.volume_id = volume_id
 
 
 @nova_base.NovaObjectRegistry.register_notification
@@ -117,45 +163,82 @@ class InstanceActionVolumeSwapPayload(InstanceActionPayload):
     # No SCHEMA as all the additional fields are calculated
 
     # Version 1.1: locked and display_description added to InstancePayload
-    VERSION = '1.1'
+    # Version 1.2: Added auto_disk_config field to InstancePayload
+    # Version 1.3: Added key_name field to InstancePayload
+    # Version 1.4: Add BDM related data
+    # Version 1.5: Added updated_at field to InstancePayload
+    VERSION = '1.5'
     fields = {
         'old_volume_id': fields.UUIDField(),
         'new_volume_id': fields.UUIDField(),
     }
 
-    def __init__(self, instance, fault, ip_addresses, flavor,
-                 old_volume_id, new_volume_id):
+    def __init__(self, instance, fault, old_volume_id, new_volume_id):
         super(InstanceActionVolumeSwapPayload, self).__init__(
                 instance=instance,
-                fault=fault,
-                ip_addresses=ip_addresses,
-                flavor=flavor,
-                old_volume_id=old_volume_id,
-                new_volume_id=new_volume_id)
+                fault=fault)
+        self.old_volume_id = old_volume_id
+        self.new_volume_id = new_volume_id
+
+
+@nova_base.NovaObjectRegistry.register_notification
+class InstanceCreatePayload(InstanceActionPayload):
+    # No SCHEMA as all the additional fields are calculated
+
+    # Version 1.2: Initial version. It starts at 1.2 to match with the version
+    #              of the InstanceActionPayload at the time when this specific
+    #              payload is created as a child of it so that the
+    #              instance.create notification using this new payload does not
+    #              have decreasing version.
+    #         1.3: Add keypairs field
+    #         1.4: Add key_name field to InstancePayload
+    #         1.5: Add BDM related data to InstancePayload
+    #         1.6: Add tags field to InstanceCreatePayload
+    #         1.7: Added updated_at field to InstancePayload
+    VERSION = '1.7'
+
+    fields = {
+        'keypairs': fields.ListOfObjectsField('KeypairPayload'),
+        'tags': fields.ListOfStringsField(),
+    }
+
+    def __init__(self, instance, fault):
+        super(InstanceCreatePayload, self).__init__(
+                instance=instance,
+                fault=fault)
+        self.keypairs = [keypair_payload.KeypairPayload(keypair=keypair)
+                         for keypair in instance.keypairs]
+        self.tags = [instance_tag.tag
+                     for instance_tag in instance.tags]
 
 
 @nova_base.NovaObjectRegistry.register_notification
 class InstanceUpdatePayload(InstancePayload):
     # Version 1.0: Initial version
     # Version 1.1: locked and display_description added to InstancePayload
-    VERSION = '1.1'
+    # Version 1.2: Added tags field
+    # Version 1.3: Added auto_disk_config field to InstancePayload
+    # Version 1.4: Added key_name field to InstancePayload
+    # Version 1.5: Add BDM related data
+    # Version 1.6: Added updated_at field to InstancePayload
+    VERSION = '1.6'
     fields = {
         'state_update': fields.ObjectField('InstanceStateUpdatePayload'),
         'audit_period': fields.ObjectField('AuditPeriodPayload'),
         'bandwidth': fields.ListOfObjectsField('BandwidthPayload'),
-        'old_display_name': fields.StringField(nullable=True)
+        'old_display_name': fields.StringField(nullable=True),
+        'tags': fields.ListOfStringsField(),
     }
 
-    def __init__(self, instance, flavor, ip_addresses, state_update,
-                 audit_period, bandwidth, old_display_name):
-        super(InstanceUpdatePayload, self).__init__(
-                instance=instance,
-                flavor=flavor,
-                ip_addresses=ip_addresses,
-                state_update=state_update,
-                audit_period=audit_period,
-                bandwidth=bandwidth,
-                old_display_name=old_display_name)
+    def __init__(self, instance, state_update, audit_period, bandwidth,
+                 old_display_name):
+        super(InstanceUpdatePayload, self).__init__(instance=instance)
+        self.state_update = state_update
+        self.audit_period = audit_period
+        self.bandwidth = bandwidth
+        self.old_display_name = old_display_name
+        self.tags = [instance_tag.tag
+                     for instance_tag in instance.tags.objects]
 
 
 @nova_base.NovaObjectRegistry.register_notification
@@ -172,6 +255,17 @@ class IpPayload(base.NotificationPayloadBase):
         'device_name': fields.StringField(nullable=True)
     }
 
+    def __init__(self, label, mac, meta, port_uuid, version, address,
+                 device_name):
+        super(IpPayload, self).__init__()
+        self.label = label
+        self.mac = mac
+        self.meta = meta
+        self.port_uuid = port_uuid
+        self.version = version
+        self.address = address
+        self.device_name = device_name
+
     @classmethod
     def from_network_info(cls, network_info):
         """Returns a list of IpPayload object based on the passed
@@ -202,6 +296,12 @@ class BandwidthPayload(base.NotificationPayloadBase):
         'out_bytes': fields.IntegerField(),
     }
 
+    def __init__(self, network_name, in_bytes, out_bytes):
+        super(BandwidthPayload, self).__init__()
+        self.network_name = network_name
+        self.in_bytes = in_bytes
+        self.out_bytes = out_bytes
+
 
 @nova_base.NovaObjectRegistry.register_notification
 class AuditPeriodPayload(base.NotificationPayloadBase):
@@ -212,6 +312,53 @@ class AuditPeriodPayload(base.NotificationPayloadBase):
         'audit_period_ending': fields.DateTimeField(),
     }
 
+    def __init__(self, audit_period_beginning, audit_period_ending):
+        super(AuditPeriodPayload, self).__init__()
+        self.audit_period_beginning = audit_period_beginning
+        self.audit_period_ending = audit_period_ending
+
+
+@nova_base.NovaObjectRegistry.register_notification
+class BlockDevicePayload(base.NotificationPayloadBase):
+    # Version 1.0: Initial version
+    VERSION = '1.0'
+
+    SCHEMA = {
+        'device_name': ('bdm', 'device_name'),
+        'boot_index': ('bdm', 'boot_index'),
+        'delete_on_termination': ('bdm', 'delete_on_termination'),
+        'volume_id': ('bdm', 'volume_id'),
+        'tag': ('bdm', 'tag')
+    }
+
+    fields = {
+        'device_name': fields.StringField(nullable=True),
+        'boot_index': fields.IntegerField(nullable=True),
+        'delete_on_termination': fields.BooleanField(default=False),
+        'volume_id': fields.UUIDField(),
+        'tag': fields.StringField(nullable=True)
+    }
+
+    def __init__(self, bdm):
+        super(BlockDevicePayload, self).__init__()
+        self.populate_schema(bdm=bdm)
+
+    @classmethod
+    def from_instance(cls, instance):
+        """Returns a list of BlockDevicePayload objects based on the passed
+        bdms.
+        """
+        if not CONF.notifications.bdms_in_notifications:
+            return None
+
+        instance_bdms = instance.get_bdms()
+        bdms = []
+        if instance_bdms is not None:
+            for bdm in instance_bdms:
+                if bdm.volume_id is not None:
+                    bdms.append(cls(bdm))
+        return bdms
+
 
 @nova_base.NovaObjectRegistry.register_notification
 class InstanceStateUpdatePayload(base.NotificationPayloadBase):
@@ -224,6 +371,13 @@ class InstanceStateUpdatePayload(base.NotificationPayloadBase):
         'new_task_state': fields.StringField(nullable=True),
     }
 
+    def __init__(self, old_state, state, old_task_state, new_task_state):
+        super(InstanceStateUpdatePayload, self).__init__()
+        self.old_state = old_state
+        self.state = state
+        self.old_task_state = old_task_state
+        self.new_task_state = new_task_state
+
 
 @base.notification_sample('instance-delete-start.json')
 @base.notification_sample('instance-delete-end.json')
@@ -239,8 +393,9 @@ class InstanceStateUpdatePayload(base.NotificationPayloadBase):
 @base.notification_sample('instance-power_on-end.json')
 @base.notification_sample('instance-power_off-start.json')
 @base.notification_sample('instance-power_off-end.json')
-# @base.notification_sample('instance-reboot-start.json')
-# @base.notification_sample('instance-reboot-end.json')
+@base.notification_sample('instance-reboot-start.json')
+@base.notification_sample('instance-reboot-end.json')
+@base.notification_sample('instance-reboot-error.json')
 @base.notification_sample('instance-shutdown-start.json')
 @base.notification_sample('instance-shutdown-end.json')
 @base.notification_sample('instance-snapshot-start.json')
@@ -264,11 +419,13 @@ class InstanceStateUpdatePayload(base.NotificationPayloadBase):
 # @base.notification_sample('instance-live_migration_post-end.json')
 # @base.notification_sample('instance-live_migration_post_dest-start.json')
 # @base.notification_sample('instance-live_migration_post_dest-end.json')
-# @base.notification_sample('instance-live_migration_rollback-start.json')
-# @base.notification_sample('instance-live_migration_rollback-end.json')
+@base.notification_sample('instance-live_migration_rollback-start.json')
+@base.notification_sample('instance-live_migration_rollback-end.json')
 # @base.notification_sample('instance-live_migration_rollback_dest-start.json')
 # @base.notification_sample('instance-live_migration_rollback_dest-end.json')
-# @base.notification_sample('instance-rebuild-error.json')
+@base.notification_sample('instance-rebuild-start.json')
+@base.notification_sample('instance-rebuild-end.json')
+@base.notification_sample('instance-rebuild-error.json')
 # @base.notification_sample('instance-remove_fixed_ip-start.json')
 # @base.notification_sample('instance-remove_fixed_ip-end.json')
 # @base.notification_sample('instance-resize_confirm-start.json')
@@ -278,17 +435,14 @@ class InstanceStateUpdatePayload(base.NotificationPayloadBase):
 # @base.notification_sample('instance-resize_revert-end.json')
 @base.notification_sample('instance-shelve_offload-start.json')
 @base.notification_sample('instance-shelve_offload-end.json')
-# @base.notification_sample('instance-soft_delete-start.json')
-# @base.notification_sample('instance-soft_delete-end.json')
+@base.notification_sample('instance-soft_delete-start.json')
+@base.notification_sample('instance-soft_delete-end.json')
 # @base.notification_sample('instance-trigger_crash_dump-start.json')
 # @base.notification_sample('instance-trigger_crash_dump-end.json')
 # @base.notification_sample('instance-unrescue-start.json')
 # @base.notification_sample('instance-unrescue-end.json')
 @base.notification_sample('instance-unshelve-start.json')
 @base.notification_sample('instance-unshelve-end.json')
-@base.notification_sample('instance-create-start.json')
-@base.notification_sample('instance-create-end.json')
-@base.notification_sample('instance-create-error.json')
 @nova_base.NovaObjectRegistry.register_notification
 class InstanceActionNotification(base.NotificationBase):
     # Version 1.0: Initial version
@@ -321,3 +475,31 @@ class InstanceActionVolumeSwapNotification(base.NotificationBase):
     fields = {
         'payload': fields.ObjectField('InstanceActionVolumeSwapPayload')
     }
+
+
+@base.notification_sample('instance-volume_attach-start.json')
+@base.notification_sample('instance-volume_attach-end.json')
+@base.notification_sample('instance-volume_attach-error.json')
+@base.notification_sample('instance-volume_detach-start.json')
+@base.notification_sample('instance-volume_detach-end.json')
+@nova_base.NovaObjectRegistry.register_notification
+class InstanceActionVolumeNotification(base.NotificationBase):
+    # Version 1.0: Initial version
+    VERSION = '1.0'
+
+    fields = {
+        'payload': fields.ObjectField('InstanceActionVolumePayload')
+    }
+
+
+@base.notification_sample('instance-create-start.json')
+@base.notification_sample('instance-create-end.json')
+@base.notification_sample('instance-create-error.json')
+@nova_base.NovaObjectRegistry.register_notification
+class InstanceCreateNotification(base.NotificationBase):
+    # Version 1.0: Initial version
+    VERSION = '1.0'
+
+    fields = {
+        'payload': fields.ObjectField('InstanceCreatePayload')
+    }
