@@ -19,6 +19,8 @@
 Scheduler Service
 """
 
+import collections
+
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_serialization import jsonutils
@@ -32,6 +34,8 @@ from nova import manager
 from nova import objects
 from nova.objects import host_mapping as host_mapping_obj
 from nova import quota
+from nova.scheduler import client as scheduler_client
+from nova.scheduler import utils
 
 
 LOG = logging.getLogger(__name__)
@@ -41,14 +45,32 @@ CONF = nova.conf.CONF
 QUOTAS = quota.QUOTAS
 
 
+def _host_state_obj_to_dict(host_state):
+    limits = dict(host_state.limits)
+    # The NUMATopologyFilter can set 'numa_topology' in the limits dict
+    # to a NUMATopologyLimits object which we need to convert to a primitive
+    # before this hits jsonutils.to_primitive(). We only check for that known
+    # case specifically as we don't care about handling out of tree filters
+    # or drivers injecting non-serializable things in the limits dict.
+    if 'numa_topology' in limits:
+        limits['numa_topology'] = limits['numa_topology'].obj_to_primitive()
+    return {
+        'host': host_state.host,
+        'nodename': host_state.nodename,
+        'limits': limits
+    }
+
+
 class SchedulerManager(manager.Manager):
     """Chooses a host to run instances on."""
 
-    target = messaging.Target(version='4.3')
+    target = messaging.Target(version='4.4')
 
     _sentinel = object()
 
     def __init__(self, scheduler_driver=None, *args, **kwargs):
+        client = scheduler_client.SchedulerClient()
+        self.placement_client = client.reportclient
         if not scheduler_driver:
             scheduler_driver = CONF.scheduler.driver
         self.driver = driver.DriverManager(
@@ -82,12 +104,13 @@ class SchedulerManager(manager.Manager):
     @messaging.expected_exceptions(exception.NoValidHost)
     def select_destinations(self, ctxt,
                             request_spec=None, filter_properties=None,
-                            spec_obj=_sentinel):
+                            spec_obj=_sentinel, instance_uuids=None):
         """Returns destinations(s) best suited for this RequestSpec.
 
         The result should be a list of dicts with 'host', 'nodename' and
         'limits' as keys.
         """
+        LOG.debug("Starting to schedule for instances: %s", instance_uuids)
 
         # TODO(sbauza): Change the method signature to only accept a spec_obj
         # argument once API v5 is provided.
@@ -95,8 +118,37 @@ class SchedulerManager(manager.Manager):
             spec_obj = objects.RequestSpec.from_primitives(ctxt,
                                                            request_spec,
                                                            filter_properties)
-        dests = self.driver.select_destinations(ctxt, spec_obj)
-        return jsonutils.to_primitive(dests)
+        resources = utils.resources_from_request_spec(spec_obj)
+        alloc_reqs_by_rp_uuid, provider_summaries = None, None
+        if self.driver.USES_ALLOCATION_CANDIDATES:
+            res = self.placement_client.get_allocation_candidates(resources)
+            if res is None:
+                # We have to handle the case that we failed to connect to the
+                # Placement service and the safe_connect decorator on
+                # get_allocation_candidates returns None.
+                alloc_reqs, provider_summaries = None, None
+            else:
+                alloc_reqs, provider_summaries = res
+            if not alloc_reqs:
+                LOG.debug("Got no allocation candidates from the Placement "
+                          "API. This may be a temporary occurrence as compute "
+                          "nodes start up and begin reporting inventory to "
+                          "the Placement service.")
+                raise exception.NoValidHost(reason="")
+            else:
+                # Build a dict of lists of allocation requests, keyed by
+                # provider UUID, so that when we attempt to claim resources for
+                # a host, we can grab an allocation request easily
+                alloc_reqs_by_rp_uuid = collections.defaultdict(list)
+                for ar in alloc_reqs:
+                    for rr in ar['allocations']:
+                        rp_uuid = rr['resource_provider']['uuid']
+                        alloc_reqs_by_rp_uuid[rp_uuid].append(ar)
+
+        dests = self.driver.select_destinations(ctxt, spec_obj, instance_uuids,
+            alloc_reqs_by_rp_uuid, provider_summaries)
+        dest_dicts = [_host_state_obj_to_dict(d) for d in dests]
+        return jsonutils.to_primitive(dest_dicts)
 
     def update_aggregates(self, ctxt, aggregates):
         """Updates HostManager internal aggregates information.
