@@ -13,25 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-
 from nova.tests.functional.api_sample_tests import test_servers
 from nova.tests.unit.api.openstack.compute import test_fping
 
-CONF = cfg.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
-
 
 class FpingSampleJsonTests(test_servers.ServersSampleBase):
-    extension_name = "os-fping"
-
-    def _get_flags(self):
-        f = super(FpingSampleJsonTests, self)._get_flags()
-        f['osapi_compute_extension'] = CONF.osapi_compute_extension[:]
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.fping.Fping')
-        return f
+    sample_dir = "os-fping"
 
     def setUp(self):
         super(FpingSampleJsonTests, self).setUp()
@@ -42,9 +29,6 @@ class FpingSampleJsonTests(test_servers.ServersSampleBase):
         self.stub_out("nova.api.openstack.compute.fping."
                       "FpingController.check_fping",
                       fake_check_fping)
-        self.stub_out("nova.api.openstack.compute.legacy_v2.contrib.fping."
-                      "FpingController.check_fping",
-                      fake_check_fping)
 
     def test_get_fping(self):
         self._post_server()
