@@ -14,6 +14,7 @@
 #    under the License.
 
 import datetime
+
 import mock
 
 from nova.conductor import manager as conductor_manager
@@ -25,9 +26,8 @@ from nova.tests.unit import fake_instance
 
 
 class ServerMigrationsSampleJsonTest(test_servers.ServersSampleBase):
-    extension_name = 'server-migrations'
+    sample_dir = 'server-migrations'
     scenarios = [('v2_22', {'api_major_version': 'v2.1'})]
-    extra_extensions_to_load = ["os-migrate-server", "os-access-ips"]
 
     def setUp(self):
         """setUp method for server usage."""
@@ -47,6 +47,7 @@ class ServerMigrationsSampleJsonTest(test_servers.ServersSampleBase):
         migration = objects.Migration()
         migration.id = 1
         migration.status = 'running'
+        migration.source_compute = self.compute.host
         get_by_id_and_instance.return_value = migration
         self._do_post('servers/%s/action' % self.uuid, 'live-migrate-server',
                       {'hostname': self.compute.host})
@@ -65,7 +66,7 @@ class ServerMigrationsSampleJsonTest(test_servers.ServersSampleBase):
 
 class ServerMigrationsSamplesJsonTestV2_23(test_servers.ServersSampleBase):
     ADMIN_API = True
-    extension_name = "server-migrations"
+    sample_dir = "server-migrations"
     microversion = '2.23'
     scenarios = [('v2_23', {'api_major_version': 'v2.1'})]
     UUID_1 = '4cfba335-03d8-49b2-8c52-e69043d1e8fe'
@@ -84,10 +85,10 @@ class ServerMigrationsSamplesJsonTestV2_23(test_servers.ServersSampleBase):
             'hidden': False,
             'memory_total': 123456,
             'memory_processed': 12345,
-            'memory_remaining': 120000,
+            'memory_remaining': 111111,
             'disk_total': 234567,
             'disk_processed': 23456,
-            'disk_remaining': 230000,
+            'disk_remaining': 211111,
             'created_at': datetime.datetime(2016, 0o1, 29, 13, 42, 2),
             'updated_at': datetime.datetime(2016, 0o1, 29, 13, 42, 2),
             'deleted_at': None,
@@ -105,10 +106,10 @@ class ServerMigrationsSamplesJsonTestV2_23(test_servers.ServersSampleBase):
             'hidden': False,
             'memory_total': 456789,
             'memory_processed': 56789,
-            'memory_remaining': 45000,
+            'memory_remaining': 400000,
             'disk_total': 96789,
             'disk_processed': 6789,
-            'disk_remaining': 96000,
+            'disk_remaining': 90000,
             'created_at': datetime.datetime(2016, 0o1, 22, 13, 42, 2),
             'updated_at': datetime.datetime(2016, 0o1, 22, 13, 42, 2),
             'deleted_at': None,
@@ -162,9 +163,8 @@ class ServerMigrationsSamplesJsonTestV2_23(test_servers.ServersSampleBase):
 
 class ServerMigrationsSampleJsonTestV2_24(test_servers.ServersSampleBase):
     ADMIN_API = True
-    extension_name = "server-migrations"
+    sample_dir = "server-migrations"
     scenarios = [('v2_24', {'api_major_version': 'v2.1'})]
-    extra_extensions_to_load = ["os-migrate-server", "os-access-ips"]
 
     def setUp(self):
         """setUp method for server usage."""
