@@ -42,7 +42,7 @@ class TestServerGet(test.TestCase):
         self.start_service('scheduler')
         self.compute = self.start_service('compute')
 
-        self.useFixture(cast_as_call.CastAsCall(self.stubs))
+        self.useFixture(cast_as_call.CastAsCall(self))
         self.addCleanup(nova.tests.unit.image.fake.FakeImageService_reset)
 
         self.image_id = self.api.get_images()[0]['id']
