@@ -37,15 +37,10 @@ class RebuildVolumeBackedSameImage(integrated_helpers._IntegratedTestBase,
         self.useFixture(nova_fixtures.CinderFixture(self))
 
     def _setup_scheduler_service(self):
-        self.useFixture(nova_fixtures.PlacementFixture())
         # Add the IsolatedHostsFilter to the list of enabled filters since it
         # is not enabled by default.
         enabled_filters = CONF.filter_scheduler.enabled_filters
         enabled_filters.append('IsolatedHostsFilter')
-        # Remove the DiskFilter since we're using Placement for filtering on
-        # DISK_GB.
-        if 'DiskFilter' in enabled_filters:
-            enabled_filters.remove('DiskFilter')
         self.flags(enabled_filters=enabled_filters, group='filter_scheduler')
         return self.start_service('scheduler')
 
