@@ -210,7 +210,27 @@ class TestPlacementCheck(test.NoDBTestCase):
             "versions": [
                 {
                     "min_version": "1.0",
-                    "max_version": "1.0",
+                    "max_version": "1.10",
+                    "id": "v1.0"
+                }
+            ]
+        }
+        res = self.cmd._check_placement()
+        self.assertEqual(status.UpgradeCheckCode.SUCCESS, res.code)
+
+    @mock.patch.object(status.UpgradeCommands, "_placement_get")
+    def test_version_comparison_does_not_use_floats(self, get):
+        # NOTE(rpodolyaka): previously _check_placement() coerced the version
+        # numbers to floats prior to comparison, that would lead to failures
+        # in cases like float('1.10') < float('1.4'). As we require 1.4+ now,
+        # the _check_placement() call below will assert that version comparison
+        # continues to work correctly when Placement API versions 1.10
+        # (or newer) is released
+        get.return_value = {
+             "versions": [
+                {
+                    "min_version": "1.0",
+                    "max_version": "1.10",
                     "id": "v1.0"
                 }
             ]
@@ -231,7 +251,7 @@ class TestPlacementCheck(test.NoDBTestCase):
         }
         res = self.cmd._check_placement()
         self.assertEqual(status.UpgradeCheckCode.FAILURE, res.code)
-        self.assertIn('Placement API version 1.0 needed, you have 0.9',
+        self.assertIn('Placement API version 1.10 needed, you have 0.9',
                       res.details)
 
 
@@ -632,17 +652,6 @@ class TestUpgradeCheckResourceProviders(test.NoDBTestCase):
         # create an externally shared IP allocation pool resource provider
         self._create_resource_provider(FAKE_IP_POOL_INVENTORY)
 
-        # Stub out _count_compute_nodes to make sure we never call it without
-        # a cell-targeted context.
-        original_count_compute_nodes = (
-            status.UpgradeCommands._count_compute_nodes)
-
-        def stub_count_compute_nodes(_self, context=None):
-            self.assertIsNotNone(context.db_connection)
-            return original_count_compute_nodes(_self, context=context)
-        self.stub_out('nova.cmd.status.UpgradeCommands._count_compute_nodes',
-                      stub_count_compute_nodes)
-
         result = self.cmd._check_resource_providers()
         self.assertEqual(status.UpgradeCheckCode.SUCCESS, result.code)
         self.assertIsNone(result.details)
