@@ -21,7 +21,6 @@ import string
 import uuid
 
 import mock
-from oslo_serialization import jsonutils
 import six
 
 from nova.compute import flavors
@@ -33,7 +32,6 @@ import nova.conf
 from nova import context
 from nova import exception
 from nova.image import glance
-from nova.network import api as network_api
 from nova.network import model
 from nova import objects
 from nova.objects import base
@@ -42,6 +40,7 @@ from nova.objects import fields
 from nova import rpc
 from nova import test
 from nova.tests.unit import fake_block_device
+from nova.tests.unit import fake_crypto
 from nova.tests.unit import fake_instance
 from nova.tests.unit import fake_network
 from nova.tests.unit import fake_notifier
@@ -387,13 +386,16 @@ class DefaultDeviceNamesForInstanceTestCase(test.NoDBTestCase):
 class UsageInfoTestCase(test.TestCase):
 
     def setUp(self):
+        self.public_key = fake_crypto.get_ssh_public_key()
+        self.fingerprint = '1e:2c:9b:56:79:4b:45:77:f9:ca:7a:98:2c:b0:d5:3c'
+
         def fake_get_nw_info(cls, ctxt, instance):
             self.assertTrue(ctxt.is_admin)
             return fake_network.fake_get_instance_nw_info(self, 1, 1)
 
         super(UsageInfoTestCase, self).setUp()
-        self.stubs.Set(network_api.API, 'get_instance_nw_info',
-                       fake_get_nw_info)
+        self.stub_out('nova.network.api.get_instance_nw_info',
+                      fake_get_nw_info)
 
         fake_notifier.stub_notifier(self)
         self.addCleanup(fake_notifier.reset)
@@ -409,8 +411,8 @@ class UsageInfoTestCase(test.TestCase):
             return {'id': 1, 'properties': {'kernel_id': 1, 'ramdisk_id': 1}}
 
         self.flags(group='glance', api_servers=['http://localhost:9292'])
-        self.stubs.Set(nova.tests.unit.image.fake._FakeImageService,
-                       'show', fake_show)
+        self.stub_out('nova.tests.unit.image.fake._FakeImageService.show',
+                      fake_show)
         fake_network.set_stub_network_methods(self)
         fake_server_actions.stub_out_action_events(self)
 
@@ -514,11 +516,134 @@ class UsageInfoTestCase(test.TestCase):
         self.assertEqual(str(flavor['flavorid']), flavorid)
 
         for attr in ('display_name', 'created_at', 'launched_at',
-                     'state', 'task_state', 'display_description', 'locked'):
+                     'state', 'task_state', 'display_description', 'locked',
+                     'auto_disk_config', 'key_name'):
             self.assertIn(attr, payload, "Key %s not in payload" % attr)
 
         self.assertEqual(payload['image_uuid'], uuids.fake_image_ref)
 
+    def test_notify_about_instance_create(self):
+        keypair = objects.KeyPair(name='my-key', user_id='fake', type='ssh',
+                                  public_key=self.public_key,
+                                  fingerprint=self.fingerprint)
+        keypairs = objects.KeyPairList(objects=[keypair])
+        instance = create_instance(self.context, params={'keypairs': keypairs})
+
+        compute_utils.notify_about_instance_create(
+            self.context,
+            instance,
+            host='fake-compute',
+            phase='start')
+
+        self.assertEqual(1, len(fake_notifier.VERSIONED_NOTIFICATIONS))
+        notification = fake_notifier.VERSIONED_NOTIFICATIONS[0]
+
+        self.assertEqual('INFO', notification['priority'])
+        self.assertEqual('instance.create.start', notification['event_type'])
+        self.assertEqual('nova-compute:fake-compute',
+                         notification['publisher_id'])
+
+        payload = notification['payload']['nova_object.data']
+        self.assertEqual('fake', payload['tenant_id'])
+        self.assertEqual('fake', payload['user_id'])
+        self.assertEqual(instance['uuid'], payload['uuid'])
+
+        flavorid = flavors.get_flavor_by_name('m1.tiny')['flavorid']
+        flavor = payload['flavor']['nova_object.data']
+        self.assertEqual(flavorid, str(flavor['flavorid']))
+
+        keypairs_payload = payload['keypairs']
+        self.assertEqual(1, len(keypairs_payload))
+        keypair_data = keypairs_payload[0]['nova_object.data']
+        self.assertEqual(keypair_data,
+                         {'name': 'my-key',
+                          'user_id': 'fake',
+                          'type': 'ssh',
+                          'public_key': self.public_key,
+                          'fingerprint': self.fingerprint})
+
+        for attr in ('display_name', 'created_at', 'launched_at',
+                     'state', 'task_state', 'display_description', 'locked',
+                     'auto_disk_config'):
+            self.assertIn(attr, payload, "Key %s not in payload" % attr)
+
+        self.assertEqual(uuids.fake_image_ref, payload['image_uuid'])
+
+    def test_notify_about_instance_create_without_keypair(self):
+        instance = create_instance(self.context)
+
+        compute_utils.notify_about_instance_create(
+            self.context,
+            instance,
+            host='fake-compute',
+            phase='start')
+
+        self.assertEqual(1, len(fake_notifier.VERSIONED_NOTIFICATIONS))
+        notification = fake_notifier.VERSIONED_NOTIFICATIONS[0]
+
+        self.assertEqual('INFO', notification['priority'])
+        self.assertEqual('instance.create.start', notification['event_type'])
+        self.assertEqual('nova-compute:fake-compute',
+                         notification['publisher_id'])
+
+        payload = notification['payload']['nova_object.data']
+        self.assertEqual('fake', payload['tenant_id'])
+        self.assertEqual('fake', payload['user_id'])
+        self.assertEqual(instance['uuid'], payload['uuid'])
+
+        flavorid = flavors.get_flavor_by_name('m1.tiny')['flavorid']
+        flavor = payload['flavor']['nova_object.data']
+        self.assertEqual(flavorid, str(flavor['flavorid']))
+
+        self.assertEqual(0, len(payload['keypairs']))
+        for attr in ('display_name', 'created_at', 'launched_at',
+                     'state', 'task_state', 'display_description', 'locked',
+                     'auto_disk_config'):
+            self.assertIn(attr, payload, "Key %s not in payload" % attr)
+
+        self.assertEqual(uuids.fake_image_ref, payload['image_uuid'])
+
+    def test_notify_about_instance_create_with_tags(self):
+        instance = create_instance(self.context)
+
+        # TODO(Kevin Zheng): clean this up to pass tags as params to
+        # create_instance() once instance.create() handles tags.
+        instance.tags = objects.TagList(
+            objects=[objects.Tag(self.context, tag='tag1')])
+
+        compute_utils.notify_about_instance_create(
+            self.context,
+            instance,
+            host='fake-compute',
+            phase='start')
+
+        self.assertEqual(1, len(fake_notifier.VERSIONED_NOTIFICATIONS))
+        notification = fake_notifier.VERSIONED_NOTIFICATIONS[0]
+
+        self.assertEqual('INFO', notification['priority'])
+        self.assertEqual('instance.create.start', notification['event_type'])
+        self.assertEqual('nova-compute:fake-compute',
+                         notification['publisher_id'])
+
+        payload = notification['payload']['nova_object.data']
+        self.assertEqual('fake', payload['tenant_id'])
+        self.assertEqual('fake', payload['user_id'])
+        self.assertEqual(instance.uuid, payload['uuid'])
+
+        flavorid = flavors.get_flavor_by_name('m1.tiny')['flavorid']
+        flavor = payload['flavor']['nova_object.data']
+        self.assertEqual(flavorid, str(flavor['flavorid']))
+
+        self.assertEqual(0, len(payload['keypairs']))
+        for attr in ('display_name', 'created_at', 'launched_at',
+                     'state', 'task_state', 'display_description', 'locked',
+                     'auto_disk_config', 'tags'):
+            self.assertIn(attr, payload, "Key %s not in payload" % attr)
+
+        self.assertEqual(1, len(payload['tags']))
+        self.assertEqual('tag1', payload['tags'][0])
+        self.assertEqual(uuids.fake_image_ref, payload['image_uuid'])
+
     def test_notify_about_volume_swap(self):
         instance = create_instance(self.context)
 
@@ -731,13 +856,21 @@ class ComputeUtilsGetValFromSysMetadata(test.NoDBTestCase):
         self.assertEqual(0, result)
 
 
-class ComputeUtilsGetNWInfo(test.NoDBTestCase):
-    def test_instance_object_none_info_cache(self):
-        inst = fake_instance.fake_instance_obj('fake-context',
-                                               expected_attrs=['info_cache'])
-        self.assertIsNone(inst.info_cache)
-        result = compute_utils.get_nw_info_for_instance(inst)
-        self.assertEqual(jsonutils.dumps([]), result.json())
+class ComputeUtilsRefreshInfoCacheForInstance(test.NoDBTestCase):
+    def test_instance_info_cache_not_found(self):
+        inst = fake_instance.fake_instance_obj('fake-context')
+        net_info = model.NetworkInfo([])
+        info_cache = objects.InstanceInfoCache(network_info=net_info)
+        inst.info_cache = info_cache
+        with mock.patch.object(inst.info_cache, 'refresh',
+                        side_effect=exception.InstanceInfoCacheNotFound(
+                            instance_uuid=inst.uuid)):
+            # we expect that the raised exception is ok
+            with mock.patch.object(compute_utils.LOG, 'debug') as log_mock:
+                compute_utils.refresh_info_cache_for_instance(None, inst)
+                log_mock.assert_called_once_with(
+                    'Can not refresh info_cache because instance '
+                    'was not found', instance=inst)
 
 
 class ComputeUtilsGetRebootTypes(test.NoDBTestCase):
@@ -853,9 +986,9 @@ class ComputeUtilsTestCase(test.NoDBTestCase):
         mock_notify_usage.assert_has_calls(expected_notify_calls)
 
 
-class ComputeUtilsQuotaDeltaTestCase(test.TestCase):
+class ComputeUtilsQuotaTestCase(test.TestCase):
     def setUp(self):
-        super(ComputeUtilsQuotaDeltaTestCase, self).setUp()
+        super(ComputeUtilsQuotaTestCase, self).setUp()
         self.context = context.RequestContext('fake', 'fake')
 
     def test_upsize_quota_delta(self):
@@ -920,6 +1053,35 @@ class ComputeUtilsQuotaDeltaTestCase(test.TestCase):
         mock_reserve.assert_called_once_with(project_id=inst.project_id,
                                              user_id=inst.user_id, **deltas)
 
+    @mock.patch('nova.objects.Quotas.count_as_dict')
+    def test_check_instance_quota_exceeds_with_multiple_resources(self,
+                                                                  mock_count):
+        quotas = {'cores': 1, 'instances': 1, 'ram': 512}
+        overs = ['cores', 'instances', 'ram']
+        over_quota_args = dict(quotas=quotas,
+                               usages={'instances': 1, 'cores': 1, 'ram': 512},
+                               overs=overs)
+        e = exception.OverQuota(**over_quota_args)
+        fake_flavor = objects.Flavor(vcpus=1, memory_mb=512)
+        instance_num = 1
+        proj_count = {'instances': 1, 'cores': 1, 'ram': 512}
+        user_count = proj_count.copy()
+        mock_count.return_value = {'project': proj_count, 'user': user_count}
+        with mock.patch.object(objects.Quotas, 'limit_check_project_and_user',
+                               side_effect=e):
+            try:
+                compute_utils.check_num_instances_quota(self.context,
+                                                        fake_flavor,
+                                                        instance_num,
+                                                        instance_num)
+            except exception.TooManyInstances as e:
+                self.assertEqual('cores, instances, ram', e.kwargs['overs'])
+                self.assertEqual('1, 1, 512', e.kwargs['req'])
+                self.assertEqual('1, 1, 512', e.kwargs['used'])
+                self.assertEqual('1, 1, 512', e.kwargs['allowed'])
+            else:
+                self.fail("Exception not raised")
+
 
 class IsVolumeBackedInstanceTestCase(test.TestCase):
     def setUp(self):
