@@ -17,15 +17,11 @@ Unit Tests for nova.consoleauth.rpcapi
 """
 
 import mock
-from oslo_config import cfg
-import six
 
 from nova.consoleauth import rpcapi as consoleauth_rpcapi
 from nova import context
 from nova import test
 
-CONF = cfg.CONF
-
 
 class ConsoleAuthRpcAPITestCase(test.NoDBTestCase):
     DROPPED_ARG = object()
@@ -37,12 +33,13 @@ class ConsoleAuthRpcAPITestCase(test.NoDBTestCase):
 
         rpcapi = consoleauth_rpcapi.ConsoleAuthAPI()
         self.assertIsNotNone(rpcapi.client)
-        self.assertEqual(rpcapi.client.target.topic, CONF.consoleauth_topic)
+        self.assertEqual(rpcapi.client.target.topic,
+                         consoleauth_rpcapi.RPC_TOPIC)
 
         orig_prepare = rpcapi.client.prepare
 
         version = kwargs.pop('version', None)
-        rpc_kwargs = {k: v for k, v in six.iteritems(kwargs)
+        rpc_kwargs = {k: v for k, v in kwargs.items()
                       if v is not self.DROPPED_ARG}
 
         with test.nested(
