@@ -12,10 +12,8 @@
 
 from oslo_utils import versionutils
 
-from nova.compute import arch
-from nova.compute import hv_type
-from nova.compute import vm_mode
 from nova import objects
+from nova.objects import fields as obj_fields
 from nova.scheduler.filters import image_props_filter
 from nova import test
 from nova.tests.unit.scheduler import fakes
@@ -30,122 +28,147 @@ class TestImagePropsFilter(test.NoDBTestCase):
     def test_image_properties_filter_passes_same_inst_props_and_version(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                img_hv_type=hv_type.KVM,
-                hw_vm_mode=vm_mode.HVM,
+                hw_architecture=obj_fields.Architecture.X86_64,
+                img_hv_type=obj_fields.HVType.KVM,
+                hw_vm_mode=obj_fields.VMMode.HVM,
                 img_hv_requested_version='>=6.0,<6.2'))
         spec_obj = objects.RequestSpec(image=img_props)
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_fails_different_inst_props(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.ARMV7,
-                img_hv_type=hv_type.QEMU,
-                hw_vm_mode=vm_mode.HVM))
+                hw_architecture=obj_fields.Architecture.ARMV7,
+                img_hv_type=obj_fields.HVType.QEMU,
+                hw_vm_mode=obj_fields.VMMode.HVM))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertFalse(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_fails_different_hyper_version(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                img_hv_type=hv_type.KVM,
-                hw_vm_mode=vm_mode.HVM,
+                hw_architecture=obj_fields.Architecture.X86_64,
+                img_hv_type=obj_fields.HVType.KVM,
+                hw_vm_mode=obj_fields.VMMode.HVM,
                 img_hv_requested_version='>=6.2'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'enabled': True,
-                        'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'enabled': True,
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertFalse(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_passes_partial_inst_props(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                hw_vm_mode=vm_mode.HVM))
+                hw_architecture=obj_fields.Architecture.X86_64,
+                hw_vm_mode=obj_fields.VMMode.HVM))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_fails_partial_inst_props(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                hw_vm_mode=vm_mode.HVM))
+                hw_architecture=obj_fields.Architecture.X86_64,
+                hw_vm_mode=obj_fields.VMMode.HVM))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.XEN, vm_mode.XEN)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.XEN,
+                obj_fields.VMMode.XEN)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertFalse(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_passes_without_inst_props(self):
         spec_obj = objects.RequestSpec(image=None)
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_fails_without_host_props(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                img_hv_type=hv_type.KVM,
-                hw_vm_mode=vm_mode.HVM))
+                hw_architecture=obj_fields.Architecture.X86_64,
+                img_hv_type=obj_fields.HVType.KVM,
+                hw_vm_mode=obj_fields.VMMode.HVM))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'enabled': True,
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'enabled': True,
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertFalse(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_passes_without_hyper_version(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                img_hv_type=hv_type.KVM,
-                hw_vm_mode=vm_mode.HVM,
+                hw_architecture=obj_fields.Architecture.X86_64,
+                img_hv_type=obj_fields.HVType.KVM,
+                hw_vm_mode=obj_fields.VMMode.HVM,
                 img_hv_requested_version='>=6.0'))
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'enabled': True,
-                        'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)]}
+        capabilities = {
+            'enabled': True,
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)]}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
     def test_image_properties_filter_fails_with_unsupported_hyper_ver(self):
         img_props = objects.ImageMeta(
             properties=objects.ImageMetaProps(
-                hw_architecture=arch.X86_64,
-                img_hv_type=hv_type.KVM,
-                hw_vm_mode=vm_mode.HVM,
+                hw_architecture=obj_fields.Architecture.X86_64,
+                img_hv_type=obj_fields.HVType.KVM,
+                hw_vm_mode=obj_fields.VMMode.HVM,
                 img_hv_requested_version='>=6.0'))
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'enabled': True,
-                        'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': 5000}
+        capabilities = {
+            'enabled': True,
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': 5000}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertFalse(self.filt_cls.host_passes(host, spec_obj))
 
@@ -156,9 +179,12 @@ class TestImagePropsFilter(test.NoDBTestCase):
                 hw_vm_mode='pv'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.XEN, vm_mode.XEN)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.XEN,
+                obj_fields.VMMode.XEN)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
@@ -169,9 +195,12 @@ class TestImagePropsFilter(test.NoDBTestCase):
                 hw_vm_mode='hv'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.X86_64, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.X86_64,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
@@ -182,9 +211,12 @@ class TestImagePropsFilter(test.NoDBTestCase):
                 hw_architecture='x86_32'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.I686, hv_type.KVM, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.I686,
+                obj_fields.HVType.KVM,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
@@ -195,9 +227,12 @@ class TestImagePropsFilter(test.NoDBTestCase):
                 img_hv_type='xapi'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.I686, hv_type.XEN, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.I686,
+                obj_fields.HVType.XEN,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
 
@@ -209,8 +244,11 @@ class TestImagePropsFilter(test.NoDBTestCase):
                 hw_vm_mode='baremetal'))
         hypervisor_version = versionutils.convert_version_to_int('6.0.0')
         spec_obj = objects.RequestSpec(image=img_props)
-        capabilities = {'supported_instances':
-                        [(arch.I686, hv_type.BAREMETAL, vm_mode.HVM)],
-                        'hypervisor_version': hypervisor_version}
+        capabilities = {
+            'supported_instances': [(
+                obj_fields.Architecture.I686,
+                obj_fields.HVType.BAREMETAL,
+                obj_fields.VMMode.HVM)],
+            'hypervisor_version': hypervisor_version}
         host = fakes.FakeHostState('host1', 'node1', capabilities)
         self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
