@@ -22,6 +22,8 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 
 import nova.conf
+from nova import exception
+from nova.i18n import _
 from nova.objects import migrate_data as migrate_data_obj
 from nova.virt.hyperv import block_device_manager
 from nova.virt.hyperv import imagecache
@@ -129,9 +131,16 @@ class LiveMigrationOps(object):
                   instance=instance_ref)
 
         migrate_data = migrate_data_obj.HyperVLiveMigrateData()
-        migrate_data.is_shared_instance_path = (
-            self._pathutils.check_remote_instances_dir_shared(
-                instance_ref.host))
+
+        try:
+            # The remote instance dir might not exist or other issue to cause
+            # OSError in check_remote_instances_dir_shared function
+            migrate_data.is_shared_instance_path = (
+                self._pathutils.check_remote_instances_dir_shared(
+                    instance_ref.host))
+        except exception.FileNotFound as e:
+            reason = _('Unavailable instance location: %s') % e
+            raise exception.MigrationPreCheckError(reason=reason)
         return migrate_data
 
     def cleanup_live_migration_destination_check(self, ctxt, dest_check_data):
