@@ -757,7 +757,8 @@ class IronicDriver(virt_driver.ComputeDriver):
         # and DISK_GB resource classes in early Queens when Ironic nodes will
         # *always* return the custom resource class that represents the
         # baremetal node class in an atomic, singular unit.
-        if self._node_resources_unavailable(node):
+        if (not self._node_resources_used(node) and
+            self._node_resources_unavailable(node)):
             # TODO(dtantsur): report resources as reserved instead of reporting
             # an empty inventory
             LOG.debug('Node %(node)s is not ready for a deployment, '
