@@ -48,9 +48,6 @@ import nova.conf
 from nova import context as nova_context
 from nova import exception
 from nova.i18n import _
-from nova.i18n import _LE
-from nova.i18n import _LI
-from nova.i18n import _LW
 from nova import rpc
 from nova import utils
 from nova.virt import event as virtevent
@@ -104,6 +101,8 @@ class Host(object):
         #                STOPPED lifecycle event some seconds.
         self._lifecycle_delay = 15
 
+        self._initialized = False
+
     def _native_thread(self):
         """Receives async events coming in from libvirtd.
 
@@ -147,7 +146,7 @@ class Host(object):
         try:
             handler()
         except Exception:
-            LOG.exception(_LE('Exception handling connection event'))
+            LOG.exception(_('Exception handling connection event'))
         finally:
             self._conn_event_handler_queue.task_done()
 
@@ -376,8 +375,8 @@ class Host(object):
                 self._event_lifecycle_callback,
                 self)
         except Exception as e:
-            LOG.warning(_LW("URI %(uri)s does not support events: %(error)s"),
-                     {'uri': self._uri, 'error': e})
+            LOG.warning("URI %(uri)s does not support events: %(error)s",
+                        {'uri': self._uri, 'error': e})
 
         try:
             LOG.debug("Registering for connection events: %s", str(self))
@@ -392,9 +391,9 @@ class Host(object):
             LOG.debug("The version of python-libvirt does not support "
                       "registerCloseCallback or is too old: %s", e)
         except libvirt.libvirtError as e:
-            LOG.warning(_LW("URI %(uri)s does not support connection"
-                         " events: %(error)s"),
-                     {'uri': self._uri, 'error': e})
+            LOG.warning("URI %(uri)s does not support connection"
+                        " events: %(error)s",
+                        {'uri': self._uri, 'error': e})
 
         return wrapped_conn
 
@@ -451,7 +450,7 @@ class Host(object):
         try:
             conn = self._get_connection()
         except libvirt.libvirtError as ex:
-            LOG.exception(_LE("Connection to libvirt failed: %s"), ex)
+            LOG.exception(_("Connection to libvirt failed: %s"), ex)
             payload = dict(ip=CONF.my_ip,
                            method='_connect',
                            reason=ex)
@@ -468,6 +467,9 @@ class Host(object):
         pass
 
     def initialize(self):
+        if self._initialized:
+            return
+
         # NOTE(dkliban): Error handler needs to be registered before libvirt
         #                connection is used for the first time.  Otherwise, the
         #                handler does not get registered.
@@ -527,7 +529,7 @@ class Host(object):
 
         :returns: a nova.virt.libvirt.Guest object
         :raises exception.InstanceNotFound: The domain was not found
-        :raises exception.InternalError: A libvirt error occured
+        :raises exception.InternalError: A libvirt error occurred
         """
         return libvirt_guest.Guest(self.get_domain(instance))
 
@@ -542,7 +544,7 @@ class Host(object):
 
         :returns: a libvirt.Domain object
         :raises exception.InstanceNotFound: The domain was not found
-        :raises exception.InternalError: A libvirt error occured
+        :raises exception.InternalError: A libvirt error occurred
         """
         try:
             conn = self.get_connection()
@@ -632,7 +634,7 @@ class Host(object):
         """
         if not self._caps:
             xmlstr = self.get_connection().getCapabilities()
-            LOG.info(_LI("Libvirt host capabilities %s"), xmlstr)
+            LOG.info("Libvirt host capabilities %s", xmlstr)
             self._caps = vconfig.LibvirtConfigCaps()
             self._caps.parse_str(xmlstr)
             # NOTE(mriedem): Don't attempt to get baseline CPU features
@@ -653,8 +655,8 @@ class Host(object):
                 except libvirt.libvirtError as ex:
                     error_code = ex.get_error_code()
                     if error_code == libvirt.VIR_ERR_NO_SUPPORT:
-                        LOG.warning(_LW("URI %(uri)s does not support full set"
-                                     " of host capabilities: %(error)s"),
+                        LOG.warning("URI %(uri)s does not support full set"
+                                    " of host capabilities: %(error)s",
                                      {'uri': self._uri, 'error': ex})
                     else:
                         raise
@@ -684,10 +686,9 @@ class Host(object):
         if self._hostname is None:
             self._hostname = hostname
         elif hostname != self._hostname:
-            LOG.error(_LE('Hostname has changed from %(old)s '
-                          'to %(new)s. A restart is required to take effect.'),
-                          {'old': self._hostname,
-                           'new': hostname})
+            LOG.error('Hostname has changed from %(old)s '
+                      'to %(new)s. A restart is required to take effect.',
+                      {'old': self._hostname, 'new': hostname})
         return self._hostname
 
     def find_secret(self, usage_type, usage_id):
@@ -745,7 +746,7 @@ class Host(object):
             return secret
         except libvirt.libvirtError:
             with excutils.save_and_reraise_exception():
-                LOG.error(_LE('Error defining a secret with XML: %s'), xml)
+                LOG.error('Error defining a secret with XML: %s', xml)
 
     def delete_secret(self, usage_type, usage_id):
         """Delete a secret.
@@ -795,8 +796,8 @@ class Host(object):
                     # TODO(sahid): Use get_info...
                     dom_mem = int(guest._get_domain_info(self)[2])
                 except libvirt.libvirtError as e:
-                    LOG.warning(_LW("couldn't obtain the memory from domain:"
-                                    " %(uuid)s, exception: %(ex)s"),
+                    LOG.warning("couldn't obtain the memory from domain:"
+                                " %(uuid)s, exception: %(ex)s",
                                 {"uuid": guest.uuid, "ex": e})
                     continue
                 # skip dom0
