@@ -30,7 +30,7 @@ class LibvirtHGSTVolumeDriver(libvirt_volume.LibvirtBaseVolumeDriver):
               self).__init__(host, is_block_dev=True)
         self.connector = connector.InitiatorConnector.factory(
             'HGST', utils.get_root_helper(),
-            device_scan_attempts=CONF.libvirt.num_iscsi_scan_tries)
+            device_scan_attempts=CONF.libvirt.num_volume_scan_tries)
 
     def get_config(self, connection_info, disk_info):
         """Returns xml for libvirt."""
@@ -41,11 +41,11 @@ class LibvirtHGSTVolumeDriver(libvirt_volume.LibvirtBaseVolumeDriver):
         conf.source_path = connection_info['data']['device_path']
         return conf
 
-    def connect_volume(self, connection_info, mount_device):
+    def connect_volume(self, connection_info, disk_info, instance):
         device_info = self.connector.connect_volume(connection_info['data'])
         connection_info['data']['device_path'] = device_info['path']
 
-    def disconnect_volume(self, connection_info, disk_dev):
+    def disconnect_volume(self, connection_info, disk_dev, instance):
         self.connector.disconnect_volume(connection_info['data'], None)
         super(LibvirtHGSTVolumeDriver,
-              self).disconnect_volume(connection_info, disk_dev)
+              self).disconnect_volume(connection_info, disk_dev, instance)
