@@ -21,20 +21,15 @@ from oslo_log import log as logging
 
 import nova.conf
 from nova import exception
-from nova.i18n import _LE
-from nova.i18n import _LW
 from nova import profiler
 from nova.virt.libvirt import config as vconfig
 import nova.virt.libvirt.driver
-from nova.virt.libvirt import host
 from nova.virt.libvirt import utils as libvirt_utils
 
 LOG = logging.getLogger(__name__)
 
 CONF = nova.conf.CONF
 
-SHOULD_LOG_DISCARD_WARNING = True
-
 
 @profiler.trace_cls("volume_api")
 class LibvirtBaseVolumeDriver(object):
@@ -79,8 +74,8 @@ class LibvirtBaseVolumeDriver(object):
                         new_key = 'disk_' + k
                         setattr(conf, new_key, v)
             else:
-                LOG.warning(_LW('Unknown content in connection_info/'
-                             'qos_specs: %s'), specs)
+                LOG.warning('Unknown content in connection_info/'
+                            'qos_specs: %s', specs)
 
         # Extract access_mode control parameters
         if 'access_mode' in data and data['access_mode']:
@@ -88,31 +83,15 @@ class LibvirtBaseVolumeDriver(object):
             if access_mode in ('ro', 'rw'):
                 conf.readonly = access_mode == 'ro'
             else:
-                LOG.error(_LE('Unknown content in '
-                              'connection_info/access_mode: %s'),
+                LOG.error('Unknown content in '
+                          'connection_info/access_mode: %s',
                           access_mode)
                 raise exception.InvalidVolumeAccessMode(
                     access_mode=access_mode)
 
         # Configure usage of discard
         if data.get('discard', False) is True:
-            min_qemu = nova.virt.libvirt.driver.MIN_QEMU_DISCARD_VERSION
-            if self.host.has_min_version(
-                    hv_ver=min_qemu,
-                    hv_type=host.HV_DRIVER_QEMU):
-                conf.driver_discard = 'unmap'
-            else:
-                global SHOULD_LOG_DISCARD_WARNING
-                if SHOULD_LOG_DISCARD_WARNING:
-                    SHOULD_LOG_DISCARD_WARNING = False
-                    LOG.warning(_LW('Unable to attach %(type)s volume '
-                                    '%(serial)s with discard enabled: qemu '
-                                    '%(qemu)s or later is required.'),
-                                {
-                        'qemu': min_qemu,
-                        'serial': conf.serial,
-                        'type': connection_info['driver_volume_type']
-                    })
+            conf.driver_discard = 'unmap'
 
         if disk_info['bus'] == 'scsi':
             # The driver is responsible to create the SCSI controller
@@ -127,14 +106,18 @@ class LibvirtBaseVolumeDriver(object):
 
         return conf
 
-    def connect_volume(self, connection_info, disk_info):
+    def connect_volume(self, connection_info, disk_info, instance):
         """Connect the volume."""
         pass
 
-    def disconnect_volume(self, connection_info, disk_dev):
+    def disconnect_volume(self, connection_info, disk_dev, instance):
         """Disconnect the volume."""
         pass
 
+    def extend_volume(self, connection_info, instance):
+        """Extend the volume."""
+        raise NotImplementedError()
+
 
 class LibvirtVolumeDriver(LibvirtBaseVolumeDriver):
     """Class for volumes backed by local file."""
