@@ -24,7 +24,7 @@ from oslo_vmware import pbm
 from oslo_vmware import vim_util as vutil
 
 from nova import exception
-from nova.i18n import _, _LE, _LI
+from nova.i18n import _
 from nova.virt.vmwareapi import constants
 from nova.virt.vmwareapi import vim_util
 from nova.virt.vmwareapi import vm_util
@@ -118,8 +118,8 @@ def get_datastore(session, cluster, datastore_regex=None,
                                          "get_object_property",
                                          cluster,
                                          "datastore")
-    # If there are no hosts in the cluster then an empty string is
-    # returned
+    # If there are no datastores in the cluster then an exception is
+    # raised
     if not datastore_ret:
         raise exception.DatastoreNotFound()
 
@@ -204,6 +204,14 @@ def get_allowed_datastore_types(disk_type):
     return ALL_SUPPORTED_DS_TYPES - frozenset([constants.DATASTORE_TYPE_VSAN])
 
 
+def get_datacenter_ref(session, dc_path):
+    return session._call_method(
+        session.vim,
+        "FindByInventoryPath",
+        session.vim.service_content.searchIndex,
+        inventoryPath=dc_path)
+
+
 def file_delete(session, ds_path, dc_ref):
     LOG.debug("Deleting the datastore file %s", ds_path)
     vim = session.vim
@@ -269,7 +277,7 @@ def disk_move(session, dc_ref, src_file, dst_file):
             destDatacenter=dc_ref,
             force=False)
     session._wait_for_task(move_task)
-    LOG.info(_LI("Moved virtual disk from %(src)s to %(dst)s."),
+    LOG.info("Moved virtual disk from %(src)s to %(dst)s.",
              {'src': src_file, 'dst': dst_file})
 
 
@@ -287,7 +295,7 @@ def disk_copy(session, dc_ref, src_file, dst_file):
             destDatacenter=dc_ref,
             force=False)
     session._wait_for_task(copy_disk_task)
-    LOG.info(_LI("Copied virtual disk from %(src)s to %(dst)s."),
+    LOG.info("Copied virtual disk from %(src)s to %(dst)s.",
              {'src': src_file, 'dst': dst_file})
 
 
@@ -301,7 +309,7 @@ def disk_delete(session, dc_ref, file_path):
             name=str(file_path),
             datacenter=dc_ref)
     session._wait_for_task(delete_disk_task)
-    LOG.info(_LI("Deleted virtual disk %s."), file_path)
+    LOG.info("Deleted virtual disk %s.", file_path)
 
 
 def file_move(session, dc_ref, src_file, dst_file):
@@ -427,7 +435,7 @@ def _filter_datastores_matching_storage_policy(session, data_stores,
 
     :param data_stores: the list of retrieve result wrapped datastore objects
     :param storage_policy: the storage policy name
-    :return the list of datastores conforming to the given storage policy
+    :return: the list of datastores conforming to the given storage policy
     """
     profile_id = pbm.get_profile_id_by_name(session, storage_policy)
     if profile_id:
@@ -443,8 +451,7 @@ def _filter_datastores_matching_storage_policy(session, data_stores,
                                if oc.obj in matching_ds]
             data_stores.objects = object_contents
             return data_stores
-    LOG.error(_LE("Unable to retrieve storage policy with name %s"),
-              storage_policy)
+    LOG.error("Unable to retrieve storage policy with name %s", storage_policy)
 
 
 def _update_datacenter_cache_from_objects(session, dcs):
