@@ -17,13 +17,13 @@
 
 """VIF drivers for XenAPI."""
 
+from os_xenapi.client import host_network
 from oslo_log import log as logging
 
 from nova.compute import power_state
 import nova.conf
 from nova import exception
 from nova.i18n import _
-from nova.i18n import _LW
 from nova.network import model as network_model
 from nova.virt.xenapi import network_utils
 from nova.virt.xenapi import vm_utils
@@ -55,8 +55,8 @@ class XenVIFDriver(object):
         try:
             vif_ref = self._session.call_xenapi('VIF.create', vif_rec)
         except Exception as e:
-            LOG.warning(_LW("Failed to create vif, exception:%(exception)s, "
-                            "vif:%(vif)s"), {'exception': e, 'vif': vif})
+            LOG.warning("Failed to create vif, exception:%(exception)s, "
+                        "vif:%(vif)s", {'exception': e, 'vif': vif})
             raise exception.NovaException(
                 reason=_("Failed to create vif %s") % vif)
 
@@ -78,7 +78,7 @@ class XenVIFDriver(object):
             self._session.call_xenapi('VIF.destroy', vif_ref)
         except Exception as e:
             LOG.warning(
-                _LW("Fail to unplug vif:%(vif)s, exception:%(exception)s"),
+                "Fail to unplug vif:%(vif)s, exception:%(exception)s",
                 {'vif': vif, 'exception': e}, instance=instance)
             raise exception.NovaException(
                 reason=_("Failed to unplug vif %s") % vif)
@@ -141,6 +141,9 @@ class XenAPIBridgeDriver(XenVIFDriver):
     def plug(self, instance, vif, vm_ref=None, device=None):
         if not vm_ref:
             vm_ref = vm_utils.lookup(self._session, instance['name'])
+        if not vm_ref:
+            raise exception.VirtualInterfacePlugException(
+                "Cannot find instance %s, discard vif plug" % instance['name'])
 
         # if VIF already exists, return this vif_ref directly
         vif_ref = self._get_vif_ref(vif, vm_ref)
@@ -245,6 +248,9 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         """
         if not vm_ref:
             vm_ref = vm_utils.lookup(self._session, instance['name'])
+        if not vm_ref:
+            raise exception.VirtualInterfacePlugException(
+                "Cannot find instance %s, discard vif plug" % instance['name'])
 
         # if VIF already exists, return this vif_ref directly
         vif_ref = self._get_vif_ref(vif, vm_ref)
@@ -268,9 +274,9 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         vif_rec['MTU'] = '1500'
         vif_rec['qos_algorithm_type'] = ''
         vif_rec['qos_algorithm_params'] = {}
-        # OVS on the hypervisor monitors this key and uses it to
-        # set the iface-id attribute
-        vif_rec['other_config'] = {'nicira-iface-id': vif['id']}
+        # Deprecated: 'niciria-iface-id', will remove it in the next release
+        vif_rec['other_config'] = {'nicira-iface-id': vif['id'],
+                                   'neutron-port-id': vif['id']}
         vif_ref = self._create_vif(vif, vif_rec, vm_ref)
 
         # call XenAPI to plug vif
@@ -315,10 +321,10 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         patch_port1, tap_name = self._get_patch_port_pair_names(vif['id'])
         try:
             # delete the patch port pair
-            self._ovs_del_port(bridge_name, patch_port1)
+            host_network.ovs_del_port(self._session, bridge_name, patch_port1)
         except Exception as e:
-            LOG.warning(_LW("Failed to delete patch port pair for vif %(if)s,"
-                            " exception:%(exception)s"),
+            LOG.warning("Failed to delete patch port pair for vif %(if)s,"
+                        " exception:%(exception)s",
                         {'if': vif, 'exception': e}, instance=instance)
             raise exception.VirtualInterfaceUnplugException(
                 reason=_("Failed to delete patch port pair"))
@@ -333,7 +339,7 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
             # the VM vif (which happens when shutdown the VM), the bridge
             # won't be destroyed automatically by XAPI. So let's destroy it
             # at here.
-            self._ovs_del_br(bridge_name)
+            host_network.ovs_del_br(self._session, bridge_name)
 
             qbr_name = self._get_qbr_name(vif['id'])
             qvb_name, qvo_name = self._get_veth_pair_names(vif['id'])
@@ -345,10 +351,12 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
                 self._delete_linux_port(qbr_name, tap_name)
                 self._delete_linux_port(qbr_name, qvb_name)
                 self._delete_linux_bridge(qbr_name)
-            self._ovs_del_port(CONF.xenserver.ovs_integration_bridge, qvo_name)
+            host_network.ovs_del_port(self._session,
+                                      CONF.xenserver.ovs_integration_bridge,
+                                      qvo_name)
         except Exception as e:
-            LOG.warning(_LW("Failed to delete bridge for vif %(if)s, "
-                            "exception:%(exception)s"),
+            LOG.warning("Failed to delete bridge for vif %(if)s, "
+                        "exception:%(exception)s",
                         {'if': vif, 'exception': e}, instance=instance)
             raise exception.VirtualInterfaceUnplugException(
                 reason=_("Failed to delete bridge"))
@@ -386,9 +394,7 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
     def _device_exists(self, device):
         """Check if ethernet device exists."""
         try:
-            cmd = 'ip_link_get_dev'
-            args = {'device_name': device}
-            self._exec_dom0_cmd(cmd, args)
+            host_network.ip_link_get_dev(self._session, device)
             return True
         except Exception:
             # Swallow exception from plugin, since this indicates the device
@@ -399,8 +405,7 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         """Delete a network device only if it exists."""
         if self._device_exists(dev):
             LOG.debug("delete network device '%s'", dev)
-            args = {'device_name': dev}
-            self._exec_dom0_cmd('ip_link_del_dev', args)
+            host_network.ip_link_del_dev(self._session, dev)
 
     def _create_veth_pair(self, dev1_name, dev2_name):
         """Create a pair of veth devices with the specified names,
@@ -410,39 +415,36 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
                   {'qvb': dev1_name, 'qvo': dev2_name})
         for dev in [dev1_name, dev2_name]:
             self._delete_net_dev(dev)
-        args = {'dev1_name': dev1_name, 'dev2_name': dev2_name}
-        self._exec_dom0_cmd('ip_link_add_veth_pair', args)
+        host_network.ip_link_add_veth_pair(self._session, dev1_name, dev2_name)
         for dev in [dev1_name, dev2_name]:
-            args = {'device_name': dev, 'option': 'up'}
-            self._exec_dom0_cmd('ip_link_set_dev', args)
-            args = {'device_name': dev, 'option': 'on'}
-            self._exec_dom0_cmd('ip_link_set_promisc', args)
+            host_network.ip_link_set_dev(self._session, dev, 'up')
+            host_network.ip_link_set_promisc(self._session, dev, 'on')
 
     def _create_linux_bridge(self, vif_rec):
         """create a qbr linux bridge for neutron security group
         """
-        iface_id = vif_rec['other_config']['nicira-iface-id']
+        iface_id = vif_rec['other_config']['neutron-port-id']
         linux_br_name = self._get_qbr_name(iface_id)
         if not self._device_exists(linux_br_name):
             LOG.debug("Create linux bridge %s", linux_br_name)
-            self._brctl_add_br(linux_br_name)
-            self._brctl_set_fd(linux_br_name, '0')
-            self._brctl_set_stp(linux_br_name, 'off')
-            args = {'device_name': linux_br_name, 'option': 'up'}
-            self._exec_dom0_cmd('ip_link_set_dev', args)
+            host_network.brctl_add_br(self._session, linux_br_name)
+            host_network.brctl_set_fd(self._session, linux_br_name, '0')
+            host_network.brctl_set_stp(self._session, linux_br_name, 'off')
+            host_network.ip_link_set_dev(self._session, linux_br_name, 'up')
 
         qvb_name, qvo_name = self._get_veth_pair_names(iface_id)
         if not self._device_exists(qvo_name):
             self._create_veth_pair(qvb_name, qvo_name)
-            self._brctl_add_if(linux_br_name, qvb_name)
-            self._ovs_add_port(CONF.xenserver.ovs_integration_bridge, qvo_name)
-            self._ovs_map_external_ids(qvo_name, vif_rec)
+            host_network.brctl_add_if(self._session, linux_br_name, qvb_name)
+            host_network.ovs_create_port(
+                self._session, CONF.xenserver.ovs_integration_bridge,
+                qvo_name, iface_id, vif_rec['MAC'], 'active')
         return linux_br_name
 
     def _delete_linux_port(self, qbr_name, port_name):
         try:
             # delete port in linux bridge
-            self._brctl_del_if(qbr_name, port_name)
+            host_network.brctl_del_if(self._session, qbr_name, port_name)
             self._delete_net_dev(port_name)
         except Exception:
             LOG.debug("Fail to delete linux port %(port_name)s on bridge"
@@ -452,9 +454,8 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
     def _delete_linux_bridge(self, qbr_name):
         try:
             # delete linux bridge qbrxxx
-            args = {'device_name': qbr_name, 'option': 'down'}
-            self._exec_dom0_cmd('ip_link_set_dev', args)
-            self._brctl_del_br(qbr_name)
+            host_network.ip_link_set_dev(self._session, qbr_name, 'down')
+            host_network.brctl_del_br(self._session, qbr_name)
         except Exception:
             LOG.debug("Fail to delete linux bridge %s", qbr_name)
 
@@ -468,7 +469,7 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         network_ref = vif_rec['network']
         bridge_name = self._session.network.get_bridge(network_ref)
         network_uuid = self._session.network.get_uuid(network_ref)
-        iface_id = vif_rec['other_config']['nicira-iface-id']
+        iface_id = vif_rec['other_config']['neutron-port-id']
         patch_port1, tap_name = self._get_patch_port_pair_names(iface_id)
         LOG.debug('plug_ovs_bridge: port1=%(port1)s, port2=%(port2)s,'
                   'network_uuid=%(uuid)s, bridge_name=%(bridge_name)s',
@@ -486,9 +487,9 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
                       {'interim_bridge': bridge_name,
                        'linux_bridge': linux_br_name})
             self._create_veth_pair(tap_name, patch_port1)
-            self._brctl_add_if(linux_br_name, tap_name)
+            host_network.brctl_add_if(self._session, linux_br_name, tap_name)
             # Add port to interim bridge
-            self._ovs_add_port(bridge_name, patch_port1)
+            host_network.ovs_add_port(self._session, bridge_name, patch_port1)
 
     def create_vif_interim_network(self, vif):
         net_name = self.get_vif_interim_net_name(vif['id'])
@@ -505,8 +506,8 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
         try:
             network_ref = self._session.network.create(network_rec)
         except Exception as e:
-            LOG.warning(_LW("Failed to create interim network for vif %(if)s, "
-                            "exception:%(exception)s"),
+            LOG.warning("Failed to create interim network for vif %(if)s, "
+                        "exception:%(exception)s",
                         {'if': vif, 'exception': e})
             raise exception.VirtualInterfacePlugException(
                 _("Failed to create the interim network for vif"))
@@ -515,83 +516,3 @@ class XenAPIOpenVswitchDriver(XenVIFDriver):
     def _get_patch_port_pair_names(self, iface_id):
         return (("vif%s" % iface_id)[:network_model.NIC_NAME_LEN],
                 ("tap%s" % iface_id)[:network_model.NIC_NAME_LEN])
-
-    def _ovs_add_port(self, bridge_name, port_name):
-        cmd = 'ovs_add_port'
-        args = {'bridge_name': bridge_name,
-                'port_name': port_name
-               }
-        self._exec_dom0_cmd(cmd, args)
-
-    def _ovs_del_port(self, bridge_name, port_name):
-        cmd = 'ovs_del_port'
-        args = {'bridge_name': bridge_name,
-                'port_name': port_name
-               }
-        self._exec_dom0_cmd(cmd, args)
-
-    def _ovs_del_br(self, bridge_name):
-        cmd = 'ovs_del_br'
-        args = {'bridge_name': bridge_name}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _ovs_set_if_external_id(self, interface, extneral_id, value):
-        cmd = 'ovs_set_if_external_id'
-        args = {'interface': interface,
-                'extneral_id': extneral_id,
-                'value': value}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _ovs_map_external_ids(self, interface, vif_rec):
-        '''set external ids on the integration bridge vif
-        '''
-        mac = vif_rec['MAC']
-        iface_id = vif_rec['other_config']['nicira-iface-id']
-        vif_uuid = vif_rec['uuid']
-        status = 'active'
-
-        self._ovs_set_if_external_id(interface, 'attached-mac', mac)
-        self._ovs_set_if_external_id(interface, 'iface-id', iface_id)
-        self._ovs_set_if_external_id(interface, 'xs-vif-uuid', vif_uuid)
-        self._ovs_set_if_external_id(interface, 'iface-status', status)
-
-    def _brctl_add_if(self, bridge_name, interface_name):
-        cmd = 'brctl_add_if'
-        args = {'bridge_name': bridge_name,
-                'interface_name': interface_name}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _brctl_del_if(self, bridge_name, interface_name):
-        cmd = 'brctl_del_if'
-        args = {'bridge_name': bridge_name,
-                'interface_name': interface_name}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _brctl_del_br(self, bridge_name):
-        cmd = 'brctl_del_br'
-        args = {'bridge_name': bridge_name}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _brctl_add_br(self, bridge_name):
-        cmd = 'brctl_add_br'
-        args = {'bridge_name': bridge_name}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _brctl_set_fd(self, bridge_name, fd):
-        cmd = 'brctl_set_fd'
-        args = {'bridge_name': bridge_name,
-                'fd': fd}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _brctl_set_stp(self, bridge_name, stp_opt):
-        cmd = 'brctl_set_stp'
-        args = {'bridge_name': bridge_name,
-                'option': stp_opt}
-        self._exec_dom0_cmd(cmd, args)
-
-    def _exec_dom0_cmd(self, cmd, cmd_args):
-        args = {'cmd': cmd,
-                'args': cmd_args
-               }
-        self._session.call_plugin_serialized(
-            'xenhost.py', 'network_config', args)
